@@ -1,3 +1,5 @@
+#undef USE_MMX
+#undef OLD_PERL
 #undef ENABLE_NLS
 #undef HAVE_CATGETS
 #undef HAVE_GETTEXT
