@@ -293,6 +293,7 @@ static struct prefs vars[] = {
 #endif
 	{"auto_indent", PREFS_OFFINT (auto_indent), TYPE_BOOL},
 	{"auto_resume", PREFS_OFFINT (autoresume), TYPE_BOOL},
+	{"auto_unmark_away", PREFS_OFFINT (auto_unmark_away), TYPE_BOOL},
 	{"autodccchat", PREFS_OFFINT (autodccchat), TYPE_BOOL},
 	{"autodccsend", PREFS_OFFINT (autodccsend), TYPE_BOOL},
 	{"autodialog", PREFS_OFFINT (autodialog), TYPE_BOOL},
@@ -323,6 +324,7 @@ static struct prefs vars[] = {
 	{"dcc_blocksize", PREFS_OFFINT (dcc_blocksize), TYPE_INT},
 	{"dcc_ip", PREFS_OFFSET (dcc_ip_str), TYPE_STR},
 	{"dcc_permissions", PREFS_OFFINT (dccpermissions), TYPE_INT},
+	{"dcc_remove", PREFS_OFFINT (dcc_remove), TYPE_BOOL},
 	{"dcc_send_fillspaces", PREFS_OFFINT (dcc_send_fillspaces), TYPE_BOOL},
 	{"dcc_stall_timeout", PREFS_OFFINT (dccstalltimeout), TYPE_INT},
 	{"dcc_timeout", PREFS_OFFINT (dcctimeout), TYPE_INT},
@@ -333,9 +335,11 @@ static struct prefs vars[] = {
 	{"dialog_indent_pixels", PREFS_OFFINT (dialog_indent_pixels), TYPE_INT},
 	{"dialog_show_separator", PREFS_OFFINT (dialog_show_separator), TYPE_BOOL},
 	{"dialog_tint", PREFS_OFFINT (dialog_tint), TYPE_BOOL},
+#ifndef WIN32
 	{"dialog_tint_blue", PREFS_OFFINT (dialog_tint_blue), TYPE_INT},
 	{"dialog_tint_green", PREFS_OFFINT (dialog_tint_green), TYPE_INT},
 	{"dialog_tint_red", PREFS_OFFINT (dialog_tint_red), TYPE_INT},
+#endif
 	{"dialog_transparent", PREFS_OFFINT (dialog_transparent), TYPE_BOOL},
 	{"dialog_width", PREFS_OFFINT (dialog_width), TYPE_INT},
 	{"dialog_wordwrap", PREFS_OFFINT (dialog_wordwrap), TYPE_BOOL},
@@ -375,7 +379,9 @@ static struct prefs vars[] = {
 	{"logging", PREFS_OFFINT (logging), TYPE_BOOL},
 	{"logmask", PREFS_OFFSET (logmask), TYPE_STR},
 
+#ifndef WIN32
 	{"mail_check", PREFS_OFFINT (mail_check), TYPE_BOOL},
+#endif
 	{"mainwindow_height", PREFS_OFFINT (mainwindow_height), TYPE_INT},
 	{"mainwindow_left", PREFS_OFFINT (mainwindow_left), TYPE_INT},
 	{"mainwindow_save", PREFS_OFFINT (mainwindow_save), TYPE_BOOL},
@@ -449,15 +455,18 @@ static struct prefs vars[] = {
 	{"timestamp_logs", PREFS_OFFINT (timestamp_logs), TYPE_BOOL},
 	{"timestamp_log_format", PREFS_OFFSET (timestamp_log_format), TYPE_STR},
 	{"tint", PREFS_OFFINT (tint), TYPE_BOOL},
+#ifndef WIN32
 	{"tint_blue", PREFS_OFFINT (tint_blue), TYPE_INT},
 	{"tint_green", PREFS_OFFINT (tint_green), TYPE_INT},
 	{"tint_red", PREFS_OFFINT (tint_red), TYPE_INT},
+#endif
 	{"topicbar", PREFS_OFFINT (topicbar), TYPE_BOOL},
 	{"transparent", PREFS_OFFINT (transparent), TYPE_BOOL},
 #ifdef USE_TRANS
 	{"trans_file", PREFS_OFFSET (trans_file), TYPE_STR},
 #endif
 	{"treeview", PREFS_OFFINT (treeview), TYPE_BOOL},
+	{"truncchans", PREFS_OFFINT (truncchans), TYPE_INT},
 
 	{"use_fontset", PREFS_OFFINT (use_fontset), TYPE_BOOL},
 	{"use_server_tab", PREFS_OFFINT (use_server_tab), TYPE_BOOL},
