@@ -29,8 +29,8 @@ void list_addentry (GSList ** list, char *cmd, char *name);
 struct prefs
 {
 	char *name;
-	int offset;
-	int type;
+	unsigned short offset;
+	unsigned short type;
 };
 
 #define TYPE_STR 1
