@@ -37,9 +37,16 @@ static void
 ctcp_reply (session *sess, char *tbuf, char *nick, char *word[],
 				char *word_eol[], char *conf)
 {
+	int oldc = prefs.perc_color;
+
 	auto_insert (tbuf, conf, word, word_eol, "", "", word_eol[5], "", "", nick);
 
+	/* must be disabled so the remote's text isn't interpreted with %xxx */
+	prefs.perc_color = 0;
+
 	handle_command (tbuf, sess, 0, 0);
+
+	prefs.perc_color = oldc;
 }
 
 static int
@@ -82,7 +89,7 @@ handle_ctcp (struct session *sess, char *outbuf, char *to, char *nick,
 	if (!strncasecmp (msg, "VERSION", 7) && !prefs.hidever)
 	{
 		sprintf (outbuf, "NOTICE %s :\001VERSION xchat "VERSION" %s\001\r\n",
-					nick, get_cpu_str ());
+					 nick, get_cpu_str ());
 		tcp_send (sess->server, outbuf);
 	}
 
