@@ -136,6 +136,12 @@ dcc_check_timeouts (void)
 				}
 			}
 			break;
+		case STAT_DONE:
+		case STAT_FAILED:
+		case STAT_ABORTED:
+			if (prefs.dcc_remove)
+				dcc_close (dcc, 0, TRUE);
+			break;
 		}
 		list = next;
 	}
@@ -479,13 +485,15 @@ dcc_read (GIOChannel *source, GIOCondition condition, struct DCC *dcc)
 				if (would_block_again ())
 					return TRUE;
 			}
+failedabort:
 			EMIT_SIGNAL (XP_TE_DCCRECVERR, dcc->serv->front_session, dcc->file,
 							 dcc->destfile, dcc->nick, NULL, 0);
 			dcc_close (dcc, STAT_FAILED, FALSE);
 			return TRUE;
 		}
 
-		write (dcc->fp, buf, n);
+		if (write (dcc->fp, buf, n) == -1) /* could be out of hdd space */
+			goto failedabort;
 		dcc->pos += n;
 		pos = htonl (dcc->pos);
 		send (dcc->sok, (char *) &pos, 4, 0);
