@@ -18,9 +18,8 @@ struct DCC
 {
 	struct server *serv;
 	struct dcc_chat *dccchat;
-	struct sockaddr_in SAddr;
-	unsigned long addr;				/* the 32bit IP number */
-	int fp;								/* file pointer */
+	unsigned long addr;			/* the 32bit IP number, host byte order */
+	int fp;							/* file pointer */
 	int sok;
 	int iotag;
 	int wiotag;
@@ -56,20 +55,24 @@ struct dccstat_info
 	int color;						  /* Display color (index into colors[] ) */
 };
 
+extern struct dccstat_info dccstat[];
+extern char *dcctypes[];
+
 void dcc_get (struct DCC *dcc);
+void dcc_resume (struct DCC *dcc);
 void dcc_check_timeouts (void);
-void dcc_send_filereq (struct session *sess, char *nick);
+void dcc_change_nick (server *serv, char *oldnick, char *newnick);
+void dcc_send_filereq (session *sess, char *nick);
 void dcc_close (struct DCC *dcc, int stat, int destroy);
 void dcc_notify_kill (struct server *serv);
-struct sockaddr_in *dcc_write_chat (char *nick, char *text);
+struct DCC *dcc_write_chat (char *nick, char *text);
 void dcc_send (struct session *sess, char *tbuf, char *to, char *file);
 struct DCC *find_dcc (char *nick, char *file, int type);
 void dcc_get_nick (struct session *sess, char *nick);
-struct DCC *new_dcc (void);
-void dcc_chat (struct session *sess, char *nick);
-void handle_dcc (struct session *sess, char *outbuf, char *nick, char *word[],
+void dcc_chat (session *sess, char *nick);
+void handle_dcc (session *sess, char *outbuf, char *nick, char *word[],
 					  char *word_eol[]);
-void dcc_show_list (struct session *sess, char *outbuf);
+void dcc_show_list (session *sess, char *outbuf);
 void open_dcc_recv_window (void);
 void open_dcc_send_window (void);
 void open_dcc_chat_window (void);
