@@ -27,18 +27,15 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <fcntl.h>
+
 #include "xchat.h"
 #include "ignore.h"
 #include "plugin.h"
 #include "cfgfiles.h"
 #include "fe.h"
-
-extern GSList *ignore_list;
-
-extern int match (char *mask, char *name);	/* util.c */
-extern void PrintText (struct session *sess, unsigned char *text);	/* text.c */
-
-extern struct xchatprefs prefs;
+#include "text.h"
+#include "util.h"
+#include "xchatc.h"
 
 
 int ignored_ctcp = 0;			  /* keep a count of all we ignore */
@@ -46,7 +43,7 @@ int ignored_priv = 0;
 int ignored_chan = 0;
 int ignored_noti = 0;
 int ignored_invi = 0;
-int ignored_total = 0;
+static int ignored_total = 0;
 
 /* ignore_add(...)
 
@@ -120,29 +117,29 @@ ignore_showlist (struct session *sess)
 
 		sprintf (tbuf, " %-20s ", ig->mask);
 		if (ig->priv)
-			strcat (tbuf, "YES  ");
+			strcat (tbuf, _("YES  "));
 		else
-			strcat (tbuf, "NO   ");
+			strcat (tbuf, _("NO   "));
 		if (ig->noti)
-			strcat (tbuf, "YES  ");
+			strcat (tbuf, _("YES  "));
 		else
-			strcat (tbuf, "NO   ");
+			strcat (tbuf, _("NO   "));
 		if (ig->chan)
-			strcat (tbuf, "YES  ");
+			strcat (tbuf, _("YES  "));
 		else
-			strcat (tbuf, "NO   ");
+			strcat (tbuf, _("NO   "));
 		if (ig->ctcp)
-			strcat (tbuf, "YES  ");
+			strcat (tbuf, _("YES  "));
 		else
-			strcat (tbuf, "NO   ");
+			strcat (tbuf, _("NO   "));
 		if (ig->invi)
-			strcat (tbuf, "YES  ");
+			strcat (tbuf, _("YES  "));
 		else
-			strcat (tbuf, "NO   ");
+			strcat (tbuf, _("NO   "));
 		if (ig->unignore)
-			strcat (tbuf, "YES  ");
+			strcat (tbuf, _("YES  "));
 		else
-			strcat (tbuf, "NO   ");
+			strcat (tbuf, _("NO   "));
 		strcat (tbuf, "\n");
 		PrintText (sess, tbuf);
 		/*EMIT_SIGNAL (XP_TE_IGNORELIST, sess, ig->mask, 0, 0, 0, 0); */
@@ -304,7 +301,7 @@ ignore_load ()
 	int fh, i;
 
 	snprintf (file, sizeof file, "%s/ignore.conf", get_xdir ());
-	fh = open (file, O_RDONLY);
+	fh = open (file, O_RDONLY | OFLAGS);
 	if (fh != -1)
 	{
 		fstat (fh, &st);
@@ -341,7 +338,7 @@ ignore_save ()
 	struct ignore *ig;
 
 	snprintf (buf, sizeof buf, "%s/ignore.conf", get_xdir ());
-	fh = open (buf, O_TRUNC | O_WRONLY | O_CREAT, 0600);
+	fh = open (buf, O_TRUNC | O_WRONLY | O_CREAT | OFLAGS, 0600);
 	if (fh != -1)
 	{
 		while (temp)
@@ -370,7 +367,7 @@ ignore_save ()
 }
 
 int
-flood_check (char *nick, char *ip, struct server *serv, struct session *sess, int what)	/*0=ctcp  1=priv */
+flood_check (char *nick, char *ip, server *serv, session *sess, int what)	/*0=ctcp  1=priv */
 {
 	/*
 	   serv
@@ -380,7 +377,7 @@ flood_check (char *nick, char *ip, struct server *serv, struct session *sess, in
 	   unsigned int ctcp_number_limit;
 	   unsigned int ctcp_time_limit;
 	 */
-	char ip2[128];
+	char buf[512];
 	char real_ip[132];
 	int i;
 	time_t current_time;
@@ -399,23 +396,21 @@ flood_check (char *nick, char *ip, struct server *serv, struct session *sess, in
 				serv->ctcp_counter++;
 				if (serv->ctcp_counter == prefs.ctcp_number_limit)	/*if we reached the maximun numbers of ctcp in the seconds limits */
 				{
-					PrintText (sess, "You are being ctcp flooded from:");
-					PrintText (sess, "Nick: ");
-					PrintText (sess, nick);
-					PrintText (sess, "Ignoring only ctcp from:");
-					PrintText (sess, ip);
-
 					serv->ctcp_last_time = current_time;	/*we got the flood, restore all the vars for next one */
 					serv->ctcp_counter = 0;
 					for (i = 0; i <= 128; i++)
 						if (ip[i] == '@')
 							break;
-					snprintf (ip2, 128, "%s", &ip[i]);
-					snprintf (real_ip, 132, "*!*%s", ip2);
+					snprintf (real_ip, sizeof (real_ip), "*!*%s", &ip[i]);
 					/*ignore_add (char *mask, int priv, int noti, int chan,
 					   int ctcp, int invi, int unignore, int no_save) */
 
-					/*FIXME: only ifnore ctcp or all?, its ignoring ctcps for now */
+					snprintf (buf, sizeof (buf),
+								 "You are being CTCP flooded from %s, ignoring %s\n",
+								 nick, real_ip);
+					PrintText (sess, buf);
+
+					/*FIXME: only ignore ctcp or all?, its ignoring ctcps for now */
 					ignore_add (real_ip, 0, 0, 0, 1, 0, 0, 0);
 					return 0;
 				}
@@ -435,15 +430,16 @@ flood_check (char *nick, char *ip, struct server *serv, struct session *sess, in
 				serv->msg_counter++;
 				if (serv->msg_counter == prefs.msg_number_limit)	/*if we reached the maximun numbers of ctcp in the seconds limits */
 				{
-					PrintText (sess, "You are being msg flooded from:");
-					PrintText (sess, ip);
-					PrintText (sess, "Setting autodialog=0:");
+					snprintf (buf, sizeof (buf),
+					 "You are being MSG flooded from %s, setting autodialog OFF.\n",
+								 ip);
+					PrintText (sess, buf);
 					serv->msg_last_time = current_time;	/*we got the flood, restore all the vars for next one */
 					serv->msg_counter = 0;
 					/*ignore_add (char *mask, int priv, int noti, int chan,
 					   int ctcp, int invi, int unignore, int no_save) */
 
-					/*FIXME: only ifnore ctcp or all?, its ignoring ctcps for now */
+					/*FIXME: only ignore ctcp or all?, its ignoring ctcps for now */
 					prefs.autodialog = 0;
 					return 0;
 				}
