@@ -47,7 +47,7 @@
 /* also light/dark gray (14/15) */
 /* 5,7,8 are all shades of yellow which happen to look dman near the same */
 
-static int rcolors[] = { 3, 4, 6, 8, 9, 10, 11, 12, 13 };
+static char rcolors[] = { 3, 4, 6, 8, 9, 10, 11, 12, 13 };
 
 static int
 color_of (char *name)
@@ -56,7 +56,7 @@ color_of (char *name)
 
 	while (name[i])
 		sum += name[i++];
-	sum %= sizeof (rcolors) / sizeof (int);
+	sum %= sizeof (rcolors) / sizeof (char);
 	return rcolors[sum];
 }
 
@@ -329,7 +329,10 @@ channel_msg (struct server *serv, char *outbuf, char *chan, char *from,
 		}
 	}
 
-	if (fromme)
+	if (fromme && prefs.auto_unmark_away && serv->is_away)
+		tcp_send_len (sess->server, "AWAY\r\n", 6);
+
+	if (fromme) 
 		EMIT_SIGNAL (XP_TE_UCHANMSG, sess, from, text, nickchar, NULL, 0);
 	else if (sess->type == SESS_DIALOG)
 		EMIT_SIGNAL (XP_TE_DPRIVMSG, sess, from, text, nickchar, NULL, 0);
@@ -1025,14 +1028,14 @@ process_numeric (server * serv, session * sess, char *outbuf, int n,
 		goto def;
 	case 4:	/* check the ircd type */
 		serv->is_newtype = FALSE;
-		serv->six_modes = FALSE;
+		serv->modes_per_line = 3;		/* default to IRC RFC */
 		if (strncmp (word[5], "bahamut", 7) == 0)				/* DALNet */
 		{
 			serv->is_newtype = TRUE;		/* use the /list args */
 		} else if (strncmp (word[5], "u2.10.", 6) == 0)		/* Undernet */
 		{
 			serv->is_newtype = TRUE;		/* use the /list args */
-			serv->six_modes = TRUE;			/* allow 6 modes per line */
+			serv->modes_per_line = 6;		/* allow 6 modes per line */
 		}
 		goto def;
 	case 5:
@@ -1282,8 +1285,9 @@ process_numeric (server * serv, session * sess, char *outbuf, int n,
 			if (serv->eom_cmd)
 			{
 				handle_command (serv->eom_cmd, sess, FALSE, FALSE);
-				free (serv->eom_cmd);
-				serv->eom_cmd = NULL;
+				/*free (serv->eom_cmd);
+				serv->eom_cmd = NULL;*/
+				/* clear it on disconnect, but not reconnect */
 			}
 			check_willjoin_channels (serv, outbuf);
 			if (serv->supports_watch)
