@@ -493,8 +493,7 @@ handle_005 (server * serv, char *word[])
 	{
 		if (strncmp (word[w], "MODES=", 6) == 0)
 		{
-			if (atoi (word[w] + 6) >= 6)
-				serv->six_modes = TRUE;
+			serv->modes_per_line = atoi (word[w] + 6);
 		} else if (strncmp (word[w], "CHANTYPES=", 10) == 0)
 		{
 			free (serv->chantypes);
