@@ -28,27 +28,22 @@
 #include <fcntl.h>
 #include <unistd.h>
 #include <time.h>
+
 #include "xchat.h"
 #include "notify.h"
 #include "cfgfiles.h"
 #include "plugin.h"
 #include "fe.h"
+#include "text.h"
+#include "util.h"
+#include "xchatc.h"
 
-extern int tcp_send_len (struct server *serv, char *buf, int len);
-extern int tcp_send (struct server *serv, char *buf);
-extern void PrintText (struct session *sess, unsigned char *text);
-extern int waitline (int sok, char *buf, int bufsize);
-extern GSList *serv_list;
-extern struct session *current_tab;
-extern struct xchatprefs prefs;
 
 GSList *notify_list = 0;
-
-void notify_adduser (char *name);
-int notify_deluser (char *name);
+int notify_tag = 0;
 
 
-struct notify_per_server *
+static struct notify_per_server *
 notify_find_server_entry (struct notify *notify, struct server *serv)
 {
 	GSList *list = notify->server_list;
@@ -81,7 +76,7 @@ notify_save (void)
 
 	snprintf (buf, sizeof buf, "%s/notify.conf", get_xdir ());
 
-	fh = open (buf, O_TRUNC | O_WRONLY | O_CREAT, 0600);
+	fh = open (buf, O_TRUNC | O_WRONLY | O_CREAT | OFLAGS, 0600);
 	if (fh != -1)
 	{
 		while (list)
@@ -115,27 +110,197 @@ notify_load (void)
 	}
 }
 
-/* called when receiving a ISON 303 */
+static struct notify_per_server *
+notify_find (server *serv, char *nick)
+{
+	GSList *list = notify_list;
+	struct notify_per_server *servnot;
+	struct notify *notify;
+
+	while (list)
+	{
+		notify = (struct notify *) list->data;
+
+		servnot = notify_find_server_entry (notify, serv);
+		if (!servnot)
+		{
+			list = list->next;
+			continue;
+		}
+
+		if (!strcasecmp (notify->name, nick))
+			return servnot;
+
+		list = list->next;
+	}
+
+	return 0;
+}
+
+static void
+notify_announce_offline (server * serv, struct notify_per_server *servnot,
+								char *nick, int quiet)
+{
+	session *sess;
+
+	sess = serv->front_session;
+	if (prefs.show_notify_in_front_session && menu_sess)
+		sess = menu_sess;
+
+	servnot->ison = FALSE;
+	servnot->lastoff = time (0);
+	if (!quiet)
+		EMIT_SIGNAL (XP_TE_NOTIFYOFFLINE, sess, nick, serv->servername, NULL,
+						 NULL, 0);
+	fe_notify_update (nick);
+	fe_notify_update (0);
+}
+
+static void
+notify_announce_online (server * serv, struct notify_per_server *servnot,
+								char *nick)
+{
+	char buf[256];
+	session *sess;
+
+	sess = serv->front_session;
+	if (prefs.show_notify_in_front_session && menu_sess)
+		sess = menu_sess;
+
+	servnot->lastseen = time (0);
+	if (servnot->ison)
+		return;
+
+	servnot->ison = TRUE;
+	servnot->laston = time (0);
+	EMIT_SIGNAL (XP_TE_NOTIFYONLINE, sess, nick, serv->servername, NULL,
+					 NULL, 0);
+	fe_notify_update (nick);
+	fe_notify_update (0);
+
+	if (prefs.whois_on_notifyonline)
+	{
+		snprintf (buf, sizeof (buf), "WHOIS %s\r\n", nick);
+		tcp_send (serv, buf);
+	}
+}
+
+/* handles numeric 601 */
 
 void
-notify_markonline (struct session *sess, char *outbuf, char *word[])
+notify_set_offline (server * serv, char *nick, int quiet)
+{
+	struct notify_per_server *servnot;
+
+	servnot = notify_find (serv, nick);
+	if (!servnot)
+		return;
+
+	notify_announce_offline (serv, servnot, nick, quiet);
+}
+
+/* handles numeric 604 and 600 */
+
+void
+notify_set_online (server * serv, char *nick)
+{
+	struct notify_per_server *servnot;
+
+	servnot = notify_find (serv, nick);
+	if (!servnot)
+		return;
+
+	notify_announce_online (serv, servnot, nick);
+}
+
+static void
+notify_watch (server * serv, char *nick, int add)
+{
+	char tbuf[256];
+
+	snprintf (tbuf, sizeof (tbuf), "WATCH +%s\r\n", nick);
+	if (!add)
+		tbuf[6] = '-';
+	tcp_send (serv, tbuf);
+}
+
+static void
+notify_watch_all (char *nick, int add)
+{
+	server *serv;
+	GSList *list = serv_list;
+	while (list)
+	{
+		serv = list->data;
+		if (serv->connected && serv->end_of_motd && serv->supports_watch)
+			notify_watch (serv, nick, add);
+		list = list->next;
+	}
+}
+
+static void
+notify_flush_watches (server * serv, GSList *from, GSList *end)
+{
+	char tbuf[512];
+	GSList *list;
+	struct notify *notify;
+
+	strcpy (tbuf, "WATCH");
+
+	list = from;
+	while (list != end)
+	{
+		notify = list->data;
+		strcat (tbuf, " +");
+		strcat (tbuf, notify->name);
+		list = list->next;
+	}
+	strcat (tbuf, "\r\n");
+	tcp_send (serv, tbuf);
+}
+
+/* called when logging in. e.g. when End of motd. */
+
+void
+notify_send_watches (server * serv)
+{
+	struct notify *notify;
+	GSList *list;
+	GSList *point;
+	int len;
+
+	len = 0;
+	point = list = notify_list;
+	while (list)
+	{
+		notify = list->data;
+
+		len += strlen (notify->name) + 2 /* + and space */;
+
+		if (len > 500)
+		{
+			notify_flush_watches (serv, point, list);
+			len = 0;
+			point = list;
+		}
+
+		list = list->next;
+	}
+
+	if (point)
+		notify_flush_watches (serv, point, NULL);
+}
+
+/* called when receiving a ISON 303 - should this func go? */
+
+void
+notify_markonline (server *serv, char *word[])
 {
 	struct notify *notify;
-	struct server *serv = sess->server;
 	struct notify_per_server *servnot;
 	GSList *list = notify_list;
 	int i, seen;
 
-	if (!sess->server)
-	{
-		/*fprintf (stderr, "*** something fucked up, no sess->server\n"); */
-		return;
-	}
-
-	if (prefs.show_notify_in_front_session)
-		if (current_tab)
-			sess = current_tab;
-
 	while (list)
 	{
 		notify = (struct notify *) list->data;
@@ -152,56 +317,43 @@ notify_markonline (struct session *sess, char *outbuf, char *word[])
 			if (!strcasecmp (notify->name, word[i]))
 			{
 				seen = TRUE;
-				servnot->lastseen = time (0);
-				if (!servnot->ison)
-				{
-					char buf[128];
-
-					servnot->ison = TRUE;
-					servnot->laston = time (0);
-					EMIT_SIGNAL (XP_TE_NOTIFYONLINE, sess, notify->name,
-									 serv->servername, NULL, NULL, 0);
-					fe_notify_update (notify->name);
-
-					if (prefs.whois_on_notifyonline)
-					{
-						snprintf (buf, sizeof (buf), "WHOIS %s\r\n", notify->name);
-						tcp_send (serv, buf);
-					}
-				}
+				notify_announce_online (serv, servnot, notify->name);
 				break;
 			}
 			i++;
 			/* FIXME: word[] is only a 32 element array, limits notify list to
 			   about 27 people */
-			if (i > 27)
+			if (i > PDIWORDS - 5)
 			{
-				fprintf (stderr, "*** XCHAT WARNING: notify list too large.\n");
+				/*fprintf (stderr, _("*** XCHAT WARNING: notify list too large.\n"));*/
 				break;
 			}
 		}
 		if (!seen && servnot->ison)
 		{
-			servnot->ison = FALSE;
-			servnot->lastoff = time (0);
-			EMIT_SIGNAL (XP_TE_NOTIFYOFFLINE, sess, notify->name,
-							 serv->servername, NULL, NULL, 0);
-			fe_notify_update (notify->name);
+			notify_announce_offline (serv, servnot, notify->name, FALSE);
 		}
 		list = list->next;
 	}
 	fe_notify_update (0);
 }
 
+/* yuck! Old routine for ISON notify */
+
 int
 notify_checklist (void)
 {
-	char *outbuf = malloc (512);
+	char *outbuf;
 	struct server *serv;
 	struct notify *notify;
 	GSList *list = notify_list;
 	int i = 0;
 
+	if (!list)
+		return 1;
+
+	outbuf = malloc (512);
+
 	strcpy (outbuf, "ISON ");
 	while (list)
 	{
@@ -214,7 +366,7 @@ notify_checklist (void)
 			/* LAME: we can't send more than 512 bytes to the server, but     *
 			 * if we split it in two packets, our offline detection wouldn't  *
 			 work                                                           */
-			fprintf (stderr, "*** XCHAT WARNING: notify list too large.\n");
+			/*fprintf (stderr, _("*** XCHAT WARNING: notify list too large.\n"));*/
 			break;
 		}
 		list = list->next;
@@ -226,7 +378,7 @@ notify_checklist (void)
 		while (list)
 		{
 			serv = (struct server *) list->data;
-			if (serv->connected && serv->end_of_motd)
+			if (serv->connected && serv->end_of_motd && !serv->supports_watch)
 				tcp_send (serv, outbuf);
 			list = list->next;
 		}
@@ -244,16 +396,16 @@ notify_showlist (struct session *sess)
 	struct notify_per_server *servnot;
 	int i = 0;
 
-	PrintText (sess, "\00308,02 \002-- Notify List --------------- \003\n");
+	EMIT_SIGNAL (XP_TE_NOTIFYHEAD, sess, NULL, NULL, NULL, NULL, 0);
 	while (list)
 	{
 		i++;
 		notify = (struct notify *) list->data;
 		servnot = notify_find_server_entry (notify, sess->server);
 		if (servnot && servnot->ison)
-			sprintf (outbuf, "  %-20s online\n", notify->name);
+			sprintf (outbuf, _("  %-20s online\n"), notify->name);
 		else
-			sprintf (outbuf, "  %-20s offline\n", notify->name);
+			sprintf (outbuf, _("  %-20s offline\n"), notify->name);
 		PrintText (sess, outbuf);
 		list = list->next;
 	}
@@ -287,6 +439,7 @@ notify_deluser (char *name)
 				free (servnot);
 			}
 			notify_list = g_slist_remove (notify_list, notify);
+			notify_watch_all (name, FALSE);
 			free (notify->name);
 			free (notify);
 			fe_notify_update (0);
@@ -310,6 +463,7 @@ notify_adduser (char *name)
 		notify_checklist ();
 		fe_notify_update (notify->name);
 		fe_notify_update (0);
+		notify_watch_all (name, TRUE);
 	}
 }
 
