@@ -338,8 +338,10 @@ static int cmd_cycle (struct session *sess, char *tbuf, char *word[],
 							 char *word_eol[]);
 static int cmd_dcc (struct session *sess, char *tbuf, char *word[],
 						  char *word_eol[]);
+#if 0
 static int cmd_debug (struct session *sess, char *tbuf, char *word[],
 							 char *word_eol[]);
+#endif
 static int cmd_delbutton (struct session *sess, char *tbuf, char *word[],
 								  char *word_eol[]);
 static int cmd_deop (struct session *sess, char *tbuf, char *word[],
@@ -494,7 +496,9 @@ struct commands xc_cmds[] = {
 	 "/DCC CHAT <nick>         - offer DCC CHAT to someone\n"
 	 "/DCC CLOSE <type> <nick> <file>         example:\n"
 	 "         /dcc close send johnsmith file.tar.gz\n")},
+#if 0
 	{"DEBUG", cmd_debug, 0, 0, 0},
+#endif
 
 	{"DELBUTTON", cmd_delbutton, 0, 0,
 	 N_("/DELBUTTON <name>, deletes a button from under the user-list\n")},
@@ -675,105 +679,66 @@ help (struct session *sess, char *helpcmd, int quiet)
 		PrintText (sess, _("No such command.\n"));
 }
 
-static void
-send_channel_modes3 (struct session *sess, char *tbuf,
-							char *word[], int start, int end, char sign, char mode)
-{
-	int left;
-	int i = start;
-
-	while (1)
-	{
-		left = end - i;
-		switch (left)
-		{
-		case 0:
-			return;
-		case 1:
-			sprintf (tbuf, "MODE %s %c%c %s\r\n", sess->channel, sign, mode,
-						word[i]);
-			break;
-		case 2:
-			sprintf (tbuf, "MODE %s %c%c%c %s %s\r\n", sess->channel, sign, mode,
-						mode, word[i], word[i + 1]);
-			i++;
-			break;
-		default:
-			sprintf (tbuf, "MODE %s %c%c%c%c %s %s %s\r\n", sess->channel, sign,
-						mode, mode, mode, word[i], word[i + 1], word[i + 2]);
-			i += 2;
-			break;
-		}
-		tcp_send (sess->server, tbuf);
-		if (left < 3)
-			return;
-		i++;
-	}
-}
-
-static void
-send_channel_modes6 (struct session *sess, char *tbuf,
-							char *word[], int start, int end, char sign, char mode)
-{
-	int left;
-	int i = start;
-
-	while (1)
-	{
-		left = end - i;
-		switch (left)
-		{
-		case 0:
-			return;
-		case 1:
-			sprintf (tbuf, "MODE %s %c%c %s\r\n", sess->channel, sign, mode,
-						word[i]);
-			i += 1;
-			break;
-		case 2:
-			sprintf (tbuf, "MODE %s %c%c%c %s %s\r\n", sess->channel, sign, mode,
-						mode, word[i], word[i + 1]);
-			i += 2;
-			break;
-		case 3:
-			sprintf (tbuf, "MODE %s %c%c%c%c %s %s %s\r\n", sess->channel, sign,
-						mode, mode, mode, word[i], word[i + 1], word[i + 2]);
-			i += 3;
-			break;
-		case 4:
-			sprintf (tbuf, "MODE %s %c%c%c%c%c %s %s %s %s\r\n", sess->channel,
-						sign, mode, mode, mode, mode,
-						word[i], word[i + 1], word[i + 2], word[i + 3]);
-			i += 4;
-			break;
-		case 5:
-			sprintf (tbuf, "MODE %s %c%c%c%c%c%c %s %s %s %s %s\r\n",
-						sess->channel, sign, mode, mode, mode, mode, mode, word[i],
-						word[i + 1], word[i + 2], word[i + 3], word[i + 4]);
-			i += 5;
-			break;
-		default:
-			sprintf (tbuf, "MODE %s %c%c%c%c%c%c%c %s %s %s %s %s %s\r\n",
-						sess->channel, sign, mode, mode, mode, mode, mode, mode,
-						word[i], word[i + 1], word[i + 2], word[i + 3], word[i + 4],
-						word[i + 5]);
-			i += 6;
-			break;
-		}
-		tcp_send (sess->server, tbuf);
-		if (left < 6)
-			return;
-	}
-}
-
+/* word[] - list of nicks.
+   wpos   - index into word[]. Where nicks really start.
+   end    - index into word[]. Last entry plus one.
+   sign   - a char, e.g. '+' or '-'
+   mode   - a mode, e.g. 'o' or 'v'	*/
 void
-send_channel_modes (struct session *sess, char *tbuf,
-						  char *word[], int start, int end, char sign, char mode)
+send_channel_modes (session *sess, char *tbuf, char *word[], int wpos,
+						  int end, char sign, char mode)
 {
-	if (sess->server->six_modes)
-		send_channel_modes6 (sess, tbuf, word, start, end, sign, mode);
-	else
-		send_channel_modes3 (sess, tbuf, word, start, end, sign, mode);
+	int usable_modes, orig_len, len, wlen, i;
+
+	/* sanity check. IRC RFC says three per line. */
+	if (sess->server->modes_per_line < 3)
+		sess->server->modes_per_line = 3;
+
+	while (wpos < end)
+	{
+		orig_len = len = sprintf (tbuf, "MODE %s ", sess->channel);
+
+		/* we'll need this many modechars too */
+		len += sess->server->modes_per_line;
+
+		/* how many can we fit? */
+		for (i = 0; i < sess->server->modes_per_line; i++)
+		{
+			/* no more nicks left? */
+			if (wpos + i >= end)
+				break;
+			wlen = strlen (word[wpos + i]) + 1;
+			/* 512 is IRC max, minus 2 for \r\n, 1 for sign, 1 for OBO error */
+			if (wlen + len > 508)
+				break;
+			len += wlen; /* length of our whole string so far */
+		}
+		if (i < 1)
+			return;
+		usable_modes = i;	/* this is how many we'll send on this line */
+
+		/* add the +/-modemodemodemode */
+		len = orig_len;
+		tbuf[len] = sign;
+		len++;
+		for (i = 0; i < usable_modes; i++)
+		{
+			tbuf[len] = mode;
+			len++;
+		}
+		tbuf[len] = 0;	/* null terminate for the strcat() to work */
+
+		/* add all the nicknames */
+		for (i = 0; i < usable_modes; i++)
+		{
+			strcat (tbuf, " ");
+			strcat (tbuf, word[wpos + i]);
+		}
+		strcat (tbuf, "\r\n");
+		tcp_send (sess->server, tbuf);
+
+		wpos += usable_modes;
+	}
 }
 
 int
@@ -1266,6 +1231,7 @@ cmd_dcc (struct session *sess, char *tbuf, char *word[], char *word_eol[])
 	return TRUE;
 }
 
+#if 0
 static int
 cmd_debug (struct session *sess, char *tbuf, char *word[], char *word_eol[])
 {
@@ -1308,6 +1274,7 @@ cmd_debug (struct session *sess, char *tbuf, char *word[], char *word_eol[])
 
 	return TRUE;
 }
+#endif
 
 int
 cmd_delbutton (struct session *sess, char *tbuf, char *word[],
