@@ -23,38 +23,29 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+
 #include "xchat.h"
 #include "util.h"
 #include "plugin.h"
-#include "util.h"
 #include "fe.h"
+#include "outbound.h"
+#include "cfgfiles.h"
+#include "text.h"
+
+int current_signal;
+GSList *sigroots[NUM_XP];
+void *signal_data;
 
 #ifdef USE_PLUGIN
 
 #include <dlfcn.h>
 
-extern void notj_msg (struct session *sess);
-extern void notc_msg (struct session *sess);
-extern void PrintText (struct session *sess, unsigned char *text);
-extern char *get_xdir (void);
-
 void unhook_all_by_mod (struct module *mod);
 int module_load (char *name, struct session *sess);
 
 struct module *modules;
 struct module_cmd_set *mod_cmds;
 
-#endif
-
-int current_signal;
-GSList *sigroots[NUM_XP];
-void *signal_data;
-/*int (*sighandler[NUM_XP]) (void *, void *, void *, void *, void *, char);*/
-
-extern void printevent_setup ();
-
-#ifdef USE_PLUGIN
-
 static void
 module_autoload (char *mod)
 {
@@ -83,18 +74,13 @@ fire_signal (int s, char *a, char *b, char *c, char *d, char *e, char f)
 	struct xp_signal *sig;
 	int flag = 0;
 
-	/*current_signal = s;
-	   if (sighandler[s] == NULL)
-	   return 0;
-	   return sighandler[s] (a, b, c, d, e, f); */
-
 	cur = sigroots[s];
-	current_signal = s;
 	while (cur)
 	{
 		sig = cur->data;
 
 		signal_data = sig->data;
+		current_signal = s;
 		if (sig->callback (a, b, c, d, e, f))
 			flag = 1;
 
@@ -107,57 +93,13 @@ fire_signal (int s, char *a, char *b, char *c, char *d, char *e, char f)
 void
 unhook_signal (struct xp_signal *sig)
 {
-	/*if (sig->next != NULL)
-	   sig->next->last = sig->last;
-	   if (sig->last != NULL)
-	   {
-	   sig->last->next = sig->next;
-	   if (sig->next != NULL)
-	   *(sig->last->naddr) = sig->next->callback;
-	   else
-	   *(sig->last->naddr) = NULL;
-	   } else
-	   {
-	   if (sig->next != NULL)
-	   sighandler[sig->signal] = sig->next->callback;
-	   else
-	   sighandler[sig->signal] = NULL;
-	   }
-	   if (sig == sigroots[sig->signal])
-	   sigroots[sig->signal] = NULL;
-	 */
-
 	g_assert (sig);
-	/*g_assert (sig->signal > 0); */
-	/* if sig->signal == -1 then it is an textevent */
 	sigroots[sig->signal] = g_slist_remove (sigroots[sig->signal], sig);
 }
 
 int
 hook_signal (struct xp_signal *sig)
 {
-	/*if (sig->signal > NUM_XP || sig->signal < 0)
-	   return 1;
-	   if (sig->naddr == NULL || sig->callback == NULL)
-	   return 2;
-	   #ifdef USE_PLUGIN
-	   if (sig->mod == NULL)
-	   return 3;
-	   #endif
-
-	   sig->next = sigroots[sig->signal];
-	   if (sigroots[sig->signal] != NULL)
-	   {
-	   sigroots[sig->signal]->last = sig;
-	   *(sig->naddr) = sigroots[sig->signal]->callback;
-	   } else
-	   *(sig->naddr) = NULL;
-
-	   sig->last = NULL;
-	   sighandler[sig->signal] = sig->callback;
-	   sigroots[sig->signal] = sig;
-	 */
-
 	g_assert (sig);
 	g_assert (sig->callback);
 
@@ -169,23 +111,23 @@ hook_signal (struct xp_signal *sig)
 #ifdef USE_PLUGIN
 
 void
-module_add_cmds (struct module_cmd_set *cmds)
+module_add_cmds (struct module_cmd_set *xc_cmds)
 {
 	if (mod_cmds != NULL)
-		mod_cmds->last = cmds;
-	cmds->next = mod_cmds;
-	cmds->last = NULL;
-	mod_cmds = cmds;
+		mod_cmds->last = xc_cmds;
+	xc_cmds->next = mod_cmds;
+	xc_cmds->last = NULL;
+	mod_cmds = xc_cmds;
 }
 
 void
-module_rm_cmds (struct module_cmd_set *cmds)
+module_rm_cmds (struct module_cmd_set *xc_cmds)
 {
-	if (cmds->last != NULL)
-		cmds->last->next = cmds->next;
-	if (cmds->next != NULL)
-		cmds->next->last = cmds->last;
-	if (cmds == mod_cmds)
+	if (xc_cmds->last != NULL)
+		xc_cmds->last->next = xc_cmds->next;
+	if (xc_cmds->next != NULL)
+		xc_cmds->next->last = xc_cmds->last;
+	if (xc_cmds == mod_cmds)
 		mod_cmds = mod_cmds->next;
 }
 
@@ -288,7 +230,7 @@ module_command (char *cmd, struct session *sess, char *tbuf,
 {
 	struct module_cmd_set *m;
 	int i;
-	struct commands *cmds;
+	struct commands *xc_cmds;
 
 	m = mod_cmds;
 
@@ -296,25 +238,25 @@ module_command (char *cmd, struct session *sess, char *tbuf,
 	{
 		if (m == NULL)
 			return 1;
-		cmds = m->cmds;
+		xc_cmds = m->cmds;
 		for (i = 0;; i++)
 		{
-			if (cmds[i].name == NULL)
+			if (xc_cmds[i].name == NULL)
 				break;
-			if (strcasecmp (cmd, cmds[i].name) == 0)
+			if (strcasecmp (cmd, xc_cmds[i].name) == 0)
 			{
-				if (cmds[i].needserver && !(sess->server->connected))
+				if (xc_cmds[i].needserver && !(sess->server->connected))
 				{
 					notc_msg (sess);
 					return 0;
 				}
-				if (cmds[i].needchannel && sess->channel[0] == 0)
+				if (xc_cmds[i].needchannel && sess->channel[0] == 0)
 				{
 					notj_msg (sess);
 					return 0;
 				}
-				if (cmds[i].callback (sess, tbuf, word, word_eol) == TRUE)
-					PrintText (sess, cmds[i].help);
+				if (xc_cmds[i].callback (sess, tbuf, word, word_eol) == TRUE)
+					PrintText (sess, _(xc_cmds[i].help));
 				return FALSE;
 			}
 		}
@@ -329,18 +271,18 @@ module_list (struct session *sess, char *tbuf, char *word[], char *word_eol[])
 	struct module *mod;
 	char buf[2048];
 
-	PrintText (sess, "\nList of currently loaded modules:\n");
+	PrintText (sess, _("\nList of currently loaded modules:\n"));
 	mod = modules;
 
 	for (;;)
 	{
 		if (mod == NULL)
 			break;
-		snprintf (buf, 2048, "%s:\t%s\n", mod->name, mod->desc);
+		snprintf (buf, sizeof (buf), "%s:\t%s\n", mod->name, mod->desc);
 		PrintText (sess, buf);
 		mod = mod->next;
 	}
-	PrintText (sess, "End of module list\n\n");
+	PrintText (sess, _("End of module list\n\n"));
 
 	return TRUE;
 }
