@@ -1,6 +1,3 @@
-#include "../../config.h"
-#ifdef USE_PYTHON
-
 /* 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -41,6 +38,8 @@
      hook_command(name, func): hooks the command @name and each this it is run it calls @func passing (String name, XChat.Session session, String Tuple args)
      register(name, desc): sets the script's name and description
      hook_signal(name, func): hooks the signal @name (e.g. "XP_TE_UJOIN") and calls @func everytime that signal fires passing (String name, Int flags, XChat.Data Tuple args)
+       if the called function returns a non-zero integer, the signal won't be processed any further by xchat
+     hook_timeout(msecs, func): one-shot timer, calls @func after @msecs milliseconds have passed
      info: returns a dict (see .keys())
 
    Server:
@@ -103,12 +102,19 @@
 */
 
 #include <stdio.h>
+
 #include "xchat.h"
 #include "plugin.h"
 #include "stdlib.h"
-#include "userlist.h"
 #include "Python.h"
 #include "pys_signals.h"
+#include "fe.h"
+#include "pythonc.h"
+#include "text.h"
+#include "util.h"
+#include "cfgfiles.h"
+#include "outbound.h"
+#include "xchatc.h"
 
 #define CHECK_SESS(x) if (self->sess == NULL) {\
 PyErr_SetString (PyExc_AssertionError, "access attempt on NULL session object");\
@@ -127,6 +133,7 @@ typedef struct
 	gchar *desc;
 	GSList *cmd_hooks;
 	GSList *sig_hooks;
+	GSList *timeout_hooks;
 }
 xchat_obj;
 
@@ -156,6 +163,14 @@ typedef struct
 }
 cmd_hook;
 
+typedef struct
+{
+	gint iotag;
+	PyObject *cback;
+	xchat_obj *xchat;
+}
+timeout_hook;
+
 typedef struct
 {
 	struct xp_signal *sig;
@@ -164,18 +179,6 @@ typedef struct
 }
 sig_hook;
 
-extern GSList *serv_list;
-extern GSList *sess_list;
-extern struct session *current_tab;
-
-extern void PrintText (struct session *sess, char *text);
-extern void handle_command (char *, struct session *, int, int);
-extern int tcp_send_len (struct server *, char *, int);
-extern int hook_signal (struct xp_signal *);
-extern void unhook_signal (struct xp_signal *);
-extern int for_files (char *, char *, void callback (char *));
-extern char *get_xdir ();
-
 static void _xchat_dealloc (xchat_obj * self);
 static PyObject *_xchat_getaddr (xchat_obj * self, char *name);
 static void _server_dealloc (xchat_obj * self);
@@ -249,6 +252,7 @@ _xchat_new ()
 	self->name = NULL;
 	self->cmd_hooks = NULL;
 	self->sig_hooks = NULL;
+	self->timeout_hooks = NULL;
 
 	pys_list = g_slist_prepend (pys_list, self);
 
@@ -304,6 +308,7 @@ _xchat_dealloc (xchat_obj * self)
 	GSList *cur;
 	cmd_hook *cmd;
 	sig_hook *sh;
+	timeout_hook *timeout;
 
 	if (self->name)
 		g_free (self->name);
@@ -317,9 +322,18 @@ _xchat_dealloc (xchat_obj * self)
 		cmd = cur->data;
 		g_free (cmd->name);
 		Py_XDECREF (cmd->cback);
+		cur = g_slist_remove (cur, cmd);
 		g_free (cmd);
+	}
 
-		cur = cur->next;
+	cur = self->timeout_hooks;
+	while (cur)
+	{
+		timeout = cur->data;
+		fe_timeout_remove(timeout->iotag);
+		Py_XDECREF (timeout->cback);
+		cur = g_slist_remove (cur, timeout);
+		g_free (timeout);
 	}
 
 	cur = self->sig_hooks;
@@ -329,8 +343,8 @@ _xchat_dealloc (xchat_obj * self)
 		Py_XDECREF (sh->cback);
 		unhook_signal (sh->sig);
 		g_free (sh->sig);
+		cur = g_slist_remove (cur, sh);
 		g_free (sh);
-		cur = cur->next;
 	}
 
 	PyMem_DEL (self);
@@ -422,8 +436,9 @@ int
 pys_stock_signal_handler (void *a, void *b, void *c, void *d, void *e, char f)
 {
 	sig_hook *hook;
-	PyObject *tuple, *data, *arglist;
+	PyObject *tuple, *data, *arglist, *retobj;
 	char *name = find_name_from_signal (current_signal);
+	int retval = 0;
 
 	hook = signal_data;
 	g_assert (hook);
@@ -444,13 +459,20 @@ PyTuple_SetItem (tuple, y, data);
 	arglist = Py_BuildValue ("(s,i,O)", name, f, tuple);
 
 	PyThreadState_Swap (hook->xchat->state);
-	PyEval_CallObject (hook->cback, arglist);
+	retobj = PyEval_CallObject (hook->cback, arglist);
 	if (PyErr_Occurred ())
 		PyErr_Print ();
 
+	Py_DECREF (tuple);
 	Py_XDECREF (arglist);
+	
+	if (retobj) {
+		if (retobj != Py_None && PyInt_Check(retobj) && PyInt_AsLong(retobj))
+			retval = 1;
+		Py_DECREF(retobj);
+	}
 
-	return 0;
+	return retval;
 }
 
 static PyObject *
@@ -681,10 +703,11 @@ pysH_Einfo (sess_obj * self, PyObject * args)
 	F ("limit", limit);
 	F ("ops", ops);
 	F ("total", total);
-	F ("is_shell", is_shell);
+	F ("type", type);
+	F ("is_shell", type == SESS_SHELL);
 	F ("is_tab", is_tab);
-	F ("is_dialog", is_dialog);
-	F ("is_server", is_server);
+	F ("is_dialog", type == SESS_DIALOG);
+	F ("is_server", type == SESS_SERVER);
 #undef F
 
 	PyDict_SetItemString (map, "servername",
@@ -717,8 +740,10 @@ pysH_Eget_users (sess_obj * self, PyObject * args)
 	{
 		cur = (struct User *) list->data;
 		tuple = PyTuple_New (3);
-		g_assert (cur->hostname);
-		PyTuple_SetItem (tuple, 0, PyString_FromString (cur->hostname));
+		if (cur->hostname)
+			PyTuple_SetItem (tuple, 0, PyString_FromString (cur->hostname));
+		else
+			PyTuple_SetItem (tuple, 0, PyString_FromString ("FETCHING"));
 		PyTuple_SetItem (tuple, 1, PyInt_FromLong (cur->op));
 		PyTuple_SetItem (tuple, 2, PyInt_FromLong (cur->voice));
 		PyDict_SetItemString (map, cur->nick, tuple);
@@ -747,6 +772,56 @@ pysH_register (xchat_obj * self, PyObject * args)
 	return Py_None;
 }
 
+static int
+python_timeout (timeout_hook* hook)
+{
+
+	PyObject *arglist, *retobj;
+	arglist = Py_BuildValue ("()");
+
+	PyThreadState_Swap (hook->xchat->state);
+	retobj = PyEval_CallObject (hook->cback, arglist);
+	if (PyErr_Occurred ())
+		PyErr_Print ();
+
+	Py_XDECREF (arglist);
+	Py_XDECREF (retobj);
+
+	Py_XDECREF (hook->cback);
+	hook->xchat->timeout_hooks = g_slist_remove (hook->xchat->timeout_hooks, hook);
+	g_free(hook);
+
+	return 0;
+}
+
+static PyObject *
+pysH_hook_timeout (xchat_obj * self, PyObject * args)
+{
+	PyObject *cback;
+	long timeout;
+	timeout_hook *hook;
+
+	if (!PyArg_ParseTuple (args, "lO", &timeout, &cback))
+		return NULL;
+
+	if (!PyCallable_Check (cback))
+	{
+		PyErr_SetString (PyExc_TypeError, "parameter must be callable");
+		return NULL;
+	}
+
+	Py_XINCREF (cback);
+
+	hook = g_new0 (timeout_hook, 1);
+	hook->xchat = self;
+	hook->cback = cback;
+	hook->iotag = fe_timeout_add(timeout, python_timeout, hook);
+	self->timeout_hooks = g_slist_prepend (self->timeout_hooks, hook);
+
+	Py_XINCREF (Py_None);
+	return Py_None;
+}
+
 static PyObject *
 pysH_hook_signal (xchat_obj * self, PyObject * args)
 {
@@ -945,9 +1020,6 @@ pysH_info (xchat_obj * self, PyObject * args)
 	PyDict_SetItemString (map, "Gdk-Pixbuf", PyString_FromString ("no"));
 #endif
 
-	/* I guess this is good for compatibility -- ndap, 31 May 2000 */
-	PyDict_SetItemString (map, "Imlib", PyString_FromString ("no"));
-
 #ifdef USE_GNOME
 	PyDict_SetItemString (map, "GNOME", PyString_FromString ("yes"));
 #else
@@ -990,6 +1062,7 @@ static PyMethodDef _xchat_methods[] = {
 	{"hook_command", (PyCFunction) pysH_hook_command, METH_VARARGS},
 	{"register", (PyCFunction) pysH_register, METH_VARARGS},
 	{"hook_signal", (PyCFunction) pysH_hook_signal, METH_VARARGS},
+	{"hook_timeout", (PyCFunction) pysH_hook_timeout, METH_VARARGS},
 	{"info", (PyCFunction) pysH_info, METH_VARARGS},
 	{NULL, NULL}
 };
@@ -1054,11 +1127,8 @@ static PyMethodDef _classes[] = {
 static void
 pys_autoloadfile (char *file)
 {
-	char *buf = malloc (strlen (file) + 8);
-
-	sprintf (buf, "/pload %s", file);
-	handle_command (buf, sess_list->data, FALSE, FALSE);
-	free (buf);
+	char *words[3] = {"", "", file};
+	pys_load(NULL, NULL, words, NULL);
 }
 
 void
@@ -1110,6 +1180,7 @@ pys_pkill (struct session *sess, char *tbuf, char **word, char **word_eol)
 
 	PyThreadState_Swap (obj->state);
 	Py_EndInterpreter (obj->state);
+	PyThreadState_Swap (pys_master);
 
 	return TRUE;
 }
@@ -1142,7 +1213,7 @@ pys_cmd_handle (char *cmd, struct session *sess, char **word)
 	xchat_obj *xo;
 	cmd_hook *hook = NULL;
 	sess_obj *sess_o;
-	PyObject *tuple, *arglist;
+	PyObject *tuple, *arglist, *retobj;
 	int c, x, y;
 
 	cur = pys_list;
@@ -1173,15 +1244,21 @@ pys_cmd_handle (char *cmd, struct session *sess, char **word)
 
 	arglist = Py_BuildValue ("(s,O,O)", cmd, sess_o, tuple);
 
-	PyEval_CallObject (hook->cback, arglist);
+	PyThreadState_Swap(hook->xchat->state);
+	retobj = PyEval_CallObject (hook->cback, arglist);
 	if (PyErr_Occurred ())
 		PyErr_Print ();
 
 	Py_XDECREF (arglist);
+	Py_XDECREF (sess_o);
+	Py_XDECREF (tuple);
+	Py_XDECREF (retobj);
 
 	return TRUE;
 }
 
+/* Note: this is also called from pys_autoloadfile() with funky
+   arguments, be careful */
 int
 pys_load (struct session *sess, char *tbuf, char **word, char **word_eol)
 {
@@ -1203,12 +1280,13 @@ pys_load (struct session *sess, char *tbuf, char **word, char **word_eol)
 	if (!in)
 	{
 		PrintText (current_tab,
-					  "\017Python interpreter failed to load script\n");
+					  "\017Python script file not found or could not be opened\n");
 		return FALSE;
 	}
 	if ((tstate = Py_NewInterpreter ()) == NULL)
 	{
-		PrintText (current_tab, "\017Python interpreter failed to load\n");
+		PrintText (current_tab, "\017Python interpreter could not be created\n");
+		fclose(in);
 		return TRUE;
 	}
 	Py_InitModule ("XChat", _classes);
@@ -1216,26 +1294,26 @@ pys_load (struct session *sess, char *tbuf, char **word, char **word_eol)
 	{
 		PrintText (current_tab,
 					  "\017Python interpreter failed to import XChat\n");
+		fclose(in);
 		return TRUE;
 	}
-	PyThreadState_Swap (tstate);
 	PyRun_SimpleFile (in, word[2]);
 	if (PyErr_Occurred ())
 	{
 		PrintText (current_tab,
 					  "\017Python interpreter failed to load script\n");
 		Py_EndInterpreter (tstate);
+		fclose(in);
 		return TRUE;
 	}
 
+	fclose(in);
 	return TRUE;
 }
 
 void
 pys_kill ()
 {
-	PyThreadState (pys_master);
-	Py_Exit (0);
+	PyThreadState_Swap (pys_master);
+	Py_Finalize ();
 }
-
-#endif
