@@ -729,7 +729,14 @@ disconnect_server (session * sess, int sendquit, int err)
 
 	/* send our QUIT reason */
 	if (sendquit && serv->connected)
+	{
+		if (serv->eom_cmd)
+		{
+			free (serv->eom_cmd);
+			serv->eom_cmd = NULL;
+		}
 		server_sendquit (sess);
+	}
 
 	/* close all sockets & io tags */
 	switch (server_cleanup (serv))
@@ -894,7 +901,7 @@ traverse_http (int sok, char *serverAddr, int port)
 	char buf[128];
 	int n;
 
-	n = snprintf (buf, sizeof (buf), "CONNECT %s:%d HTTP/1.1\r\n\r\n",
+	n = snprintf (buf, sizeof (buf), "CONNECT %s:%d HTTP/1.0\r\n\r\n",
 					  serverAddr, port);
 	send (sok, buf, n, 0);
 #ifndef WIN32
