@@ -213,16 +213,18 @@ open_log_file (char *servname, char *channame)
 	{
 		channame = strdup (channame);
 		tolowerStr (channame);
-#ifdef WIN32
 		/* win32 can't handle filenames with the '|' character */
 		dir = channame;
 		while (*dir)
 		{
+#ifdef WIN32
 			if (*dir == '|')
+#else
+			if (*dir == '/')
+#endif
 				*dir = '_';
 			dir++;
 		}
-#endif
 	}
 
 	snprintf (buf, 510, "%s/xchatlogs", get_xdir ());
@@ -279,7 +281,11 @@ open_log_file (char *servname, char *channame)
 	}
 
 	free (channame);
+#ifdef WIN32
+	fd = open (buf, O_CREAT | O_APPEND | O_WRONLY | OFLAGS, S_IREAD|S_IWRITE);
+#else
 	fd = open (buf, O_CREAT | O_APPEND | O_WRONLY | OFLAGS, 0644);
+#endif
 	if (fd < 0)
 		return -1;
 	currenttime = time (NULL);
@@ -364,49 +370,44 @@ setup_logging (struct session *sess)
 char **pntevts_text;
 char **pntevts;
 
+#define pevt_generic_none_help NULL
+
 static char *pevt_join_help[] = {
 	N_("The nick of the joining person"),
 	N_("The channel being joined"),
 	N_("The host of the person"),
-	NULL
 };
 
 static char *pevt_chanaction_help[] = {
 	N_("Nickname"),
 	N_("The action"),
-	NULL
 };
 
 static char *pevt_chanmsg_help[] = {
 	N_("Nickname"),
 	N_("The text"),
 	N_("Mode char"),
-	NULL
 };
 
 static char *pevt_privmsg_help[] = {
 	N_("Nickname"),
 	N_("The message"),
-	NULL
 };
 
 static char *pevt_changenick_help[] = {
 	N_("Old nickname"),
 	N_("New nickname"),
-	NULL
 };
 
 static char *pevt_newtopic_help[] = {
 	N_("Nick of person who changed the topic"),
 	N_("Topic"),
 	N_("Channel"),
-	NULL
 };
 
 static char *pevt_topic_help[] = {
 	N_("Channel"),
 	N_("Topic"),
-	NULL
 };
 
 static char *pevt_kick_help[] = {
@@ -414,65 +415,55 @@ static char *pevt_kick_help[] = {
 	N_("The person being kicked"),
 	N_("The channel"),
 	N_("The reason"),
-	NULL
 };
 
 static char *pevt_part_help[] = {
 	N_("The nick of the person leaving"),
 	N_("The host of the person"),
 	N_("The channel"),
-	NULL
 };
 
 static char *pevt_chandate_help[] = {
 	N_("The channel"),
 	N_("The time"),
-	NULL
 };
 
 static char *pevt_topicdate_help[] = {
 	N_("The channel"),
 	N_("The creator"),
 	N_("The time"),
-	NULL
 };
 
 static char *pevt_quit_help[] = {
 	N_("Nick"),
 	N_("Reason"),
 	N_("Host"),
-	NULL
 };
 
 static char *pevt_pingrep_help[] = {
 	N_("Who it's from"),
 	N_("The time in x.x format (see below)"),
-	NULL
 };
 
 static char *pevt_notice_help[] = {
 	N_("Who it's from"),
 	N_("The message"),
-	NULL
 };
 
 static char *pevt_channotice_help[] = {
 	N_("Who it's from"),
 	N_("The Channel it's going to"),
 	N_("The message"),
-	NULL
 };
 
 static char *pevt_dprivmsg_help[] = {
 	N_("Nickname"),
 	N_("The message"),
-	NULL
 };
 
 static char *pevt_uchangenick_help[] = {
 	N_("Old nickname"),
 	N_("New nickname"),
-	NULL
 };
 
 static char *pevt_ukick_help[] = {
@@ -480,7 +471,6 @@ static char *pevt_ukick_help[] = {
 	N_("The channel"),
 	N_("The nickname of the kicker"),
 	N_("The reason"),
-	NULL
 };
 
 static char *pevt_partreason_help[] = {
@@ -488,119 +478,99 @@ static char *pevt_partreason_help[] = {
 	N_("The host of the person"),
 	N_("The channel"),
 	N_("The reason"),
-	NULL
 };
 
 static char *pevt_ctcpsnd_help[] = {
 	N_("The sound"),
 	N_("The nick of the person"),
-	NULL
 };
 
 static char *pevt_ctcpgen_help[] = {
 	N_("The CTCP event"),
 	N_("The nick of the person"),
-	NULL
 };
 
 static char *pevt_ctcpgenc_help[] = {
 	N_("The CTCP event"),
 	N_("The nick of the person"),
 	N_("The Channel it's going to"),
-	NULL
 };
 
 static char *pevt_chansetkey_help[] = {
 	N_("The nick of the person who set the key"),
 	N_("The key"),
-	NULL
 };
 
 static char *pevt_chansetlimit_help[] = {
 	N_("The nick of the person who set the limit"),
 	N_("The limit"),
-	NULL
 };
 
 static char *pevt_chanop_help[] = {
 	N_("The nick of the person who has been op'ed"),
 	N_("The nick of the person of did the op'ing"),
-	NULL
 };
 
 static char *pevt_chanhop_help[] = {
 	N_("The nick of the person who has been halfop'ed"),
 	N_("The nick of the person of did the halfop'ing"),
-	NULL
 };
 
 static char *pevt_chanvoice_help[] = {
 	N_("The nick of the person who has been voice'ed"),
 	N_("The nick of the person of did the voice'ing"),
-	NULL
 };
 
 static char *pevt_chanban_help[] = {
 	N_("The nick of the person who did the banning"),
 	N_("The ban mask"),
-	NULL
 };
 
 static char *pevt_chanrmkey_help[] = {
 	N_("The nick who removed the key"),
-	NULL
 };
 
 static char *pevt_chanrmlimit_help[] = {
 	N_("The nick who removed the limit"),
-	NULL
 };
 
 static char *pevt_chandeop_help[] = {
 	N_("The nick of the person of did the deop'ing"),
 	N_("The nick of the person who has been deop'ed"),
-	NULL
 };
 static char *pevt_chandehop_help[] = {
 	N_("The nick of the person of did the dehalfop'ing"),
 	N_("The nick of the person who has been dehalfop'ed"),
-	NULL
 };
 
 static char *pevt_chandevoice_help[] = {
 	N_("The nick of the person of did the devoice'ing"),
 	N_("The nick of the person who has been devoice'ed"),
-	NULL
 };
 
 static char *pevt_chanunban_help[] = {
 	N_("The nick of the person of did the unban'ing"),
 	N_("The ban mask"),
-	NULL
 };
 
 static char *pevt_chanexempt_help[] = {
 	N_("The nick of the person who did the exempt"),
 	N_("The exempt mask"),
-	NULL
 };
 
 static char *pevt_chanrmexempt_help[] = {
 	N_("The nick of the person removed the exempt"),
 	N_("The exempt mask"),
-	NULL
 };
 
 static char *pevt_chaninvite_help[] = {
 	N_("The nick of the person who did the invite"),
 	N_("The invite mask"),
-	NULL
 };
 
 static char *pevt_chanrminvite_help[] = {
 	N_("The nick of the person removed the invite"),
 	N_("The invite mask"),
-	NULL
 };
 
 static char *pevt_chanmodegen_help[] = {
@@ -608,7 +578,6 @@ static char *pevt_chanmodegen_help[] = {
 	N_("The mode's sign (+/-)"),
 	N_("The mode letter"),
 	N_("The channel it's being set on"),
-	NULL
 };
 
 static char *pevt_whois1_help[] = {
@@ -616,142 +585,115 @@ static char *pevt_whois1_help[] = {
 	N_("Username"),
 	N_("Host"),
 	N_("Full name"),
-	NULL
 };
 
 static char *pevt_whois2_help[] = {
 	N_("Nickname"),
 	N_("Channel Membership/\"is an IRC operator\""),
-	NULL
 };
 
 static char *pevt_whois3_help[] = {
 	N_("Nickname"),
 	N_("Server Information"),
-	NULL
 };
 
 static char *pevt_whois4_help[] = {
 	N_("Nickname"),
 	N_("Idle time"),
-	NULL
 };
 
 static char *pevt_whois4t_help[] = {
 	N_("Nickname"),
 	N_("Idle time"),
 	N_("Signon time"),
-	NULL
 };
 
 static char *pevt_whois5_help[] = {
 	N_("Nickname"),
 	N_("Away reason"),
-	NULL
 };
 
 static char *pevt_whois6_help[] = {
 	N_("Nickname"),
-	NULL
 };
 
 static char *pevt_generic_channel_help[] = {
 	N_("Channel Name"),
-	NULL
-};
-
-static char *pevt_generic_none_help[] = {
-	NULL
 };
 
 static char *pevt_servertext_help[] = {
 	N_("Text"),
-	NULL
 };
 
 static char *pevt_invited_help[] = {
 	N_("Channel Name"),
 	N_("Nick of person who invited you"),
 	N_("Server Name"),
-	NULL
 };
 
 static char *pevt_usersonchan_help[] = {
 	N_("Channel Name"),
 	N_("Users"),
-	NULL
 };
 
 static char *pevt_nickclash_help[] = {
 	N_("Nickname in use"),
 	N_("Nick being tried"),
-	NULL
 };
 
 static char *pevt_connfail_help[] = {
 	N_("Error String"),
-	NULL
 };
 
 static char *pevt_connect_help[] = {
 	N_("Host"),
 	N_("IP"),
 	N_("Port"),
-	NULL
 };
 
 static char *pevt_sconnect_help[] = {
 	N_("PID"),
-	NULL
 };
 
 static char *pevt_generic_nick_help[] = {
 	N_("Nickname"),
-	NULL
 };
 
 static char *pevt_chanmodes_help[] = {
 	N_("Channel name"),
 	N_("Modes string"),
-	NULL
 };
 
 static char *pevt_rawmodes_help[] = {
 	N_("Nickname"),
 	N_("Modes string"),
-	NULL
 };
 
 static char *pevt_kill_help[] = {
 	N_("Nickname"),
 	N_("Reason"),
-	NULL
 };
 
 static char *pevt_dccchaterr_help[] = {
 	N_("Nickname"),
 	N_("IP address"),
 	N_("port"),
-	NULL
 };
 
 static char *pevt_dccstall_help[] = {
 	N_("DCC Type"),
 	N_("Filename"),
 	N_("Nickname"),
-	NULL
 };
 
 static char *pevt_generic_file_help[] = {
 	N_("Filename"),
-	NULL
 };
 
 static char *pevt_dccrecverr_help[] = {
 	N_("Filename"),
 	N_("Destination filename"),
 	N_("Nickname"),
-	NULL
 };
 
 static char *pevt_dccrecvcomp_help[] = {
@@ -759,14 +701,12 @@ static char *pevt_dccrecvcomp_help[] = {
 	N_("Destination filename"),
 	N_("Nickname"),
 	N_("CPS"),
-	NULL
 };
 
 static char *pevt_dccconfail_help[] = {
 	N_("DCC Type"),
 	N_("Nickname"),
 	N_("Error string"),
-	NULL
 };
 
 static char *pevt_dcccon_help[] = {
@@ -774,91 +714,71 @@ static char *pevt_dcccon_help[] = {
 	N_("Nickname"),
 	N_("IP address"),
 	N_("{to|from}"),
-	NULL
 };
 
 static char *pevt_dccsendfail_help[] = {
 	N_("Filename"),
 	N_("Nickname"),
-	NULL
 };
 
 static char *pevt_dccsendcomp_help[] = {
 	N_("Filename"),
 	N_("Nickname"),
 	N_("CPS"),
-	NULL
 };
 
 static char *pevt_dccoffer_help[] = {
 	N_("Filename"),
 	N_("Nickname"),
-	NULL
 };
 
 static char *pevt_dccabort_help[] = {
 	N_("DCC type"),
 	N_("Filename"),
 	N_("Nickname"),
-	NULL
 };
 
 static char *pevt_dccresumeoffer_help[] = {
 	N_("Nickname"),
 	N_("Filename"),
 	N_("Position"),
-	NULL
 };
 
 static char *pevt_dccsendoffer_help[] = {
 	N_("Nickname"),
 	N_("Filename"),
 	N_("Size"),
-	NULL
 };
 
 static char *pevt_dccgenericoffer_help[] = {
 	N_("DCC String"),
 	N_("Nickname"),
-	NULL
 };
 
 static char *pevt_notifynumber_help[] = {
 	N_("Number of notify items"),
-	NULL
 };
 
 static char *pevt_serverlookup_help[] = {
 	N_("Servername"),
-	NULL
 };
 
 static char *pevt_servererror_help[] = {
 	N_("Text"),
-	NULL
 };
 
-/*static char *pevt_servergenmessage_help[] =
-{
-   "Text",
-   NULL
-};*/
-
 static char *pevt_foundip_help[] = {
 	N_("IP"),
-	NULL
 };
 
 static char *pevt_dccrename_help[] = {
 	N_("Old Filename"),
 	N_("New Filename"),
-	NULL
 };
 
 static char *pevt_ctcpsend_help[] = {
 	N_("Receiver"),
 	N_("Message"),
-	NULL
 };
 
 static char *pevt_ignorelist_help[] = {
@@ -869,41 +789,34 @@ static char *pevt_ignorelist_help[] = {
 	N_("Ctcp Yes/No"),
 	N_("Invi Yes/No"),
 	N_("Unig Yes/No"),
-	NULL
 };
 
 static char *pevt_ignoreaddremove_help[] = {
 	N_("Hostmask"),
-	NULL
 };
 
 static char *pevt_resolvinguser_help[] = {
 	N_("Nickname"),
 	N_("Hostname"),
-	NULL
 };
 
 static char *pevt_dccmalformed_help[] = {
 	N_("The Packet"),
-	NULL
 };
 
 static char *pevt_newmail_help[] = {
 	N_("Number of messages"),
 	N_("Bytes in mailbox"),
-	NULL
 };
 
 static char *pevt_pingtimeout_help[] = {
 	N_("Seconds"),
-	NULL
 };
 
 static char *pevt_uinvite_help[] = {
 	N_("Nick of person who have been invited"),
 	N_("Channel Name"),
 	N_("Server Name"),
-	NULL
 };
 
 static char *pevt_banlist_help[] = {
@@ -911,7 +824,10 @@ static char *pevt_banlist_help[] = {
 	N_("Banmask"),
 	N_("Who set the ban"),
 	N_("Ban time"),
-	NULL
+};
+
+static char *pevt_discon_help[] = {
+	N_("Error"),
 };
 
 struct text_event
@@ -1084,7 +1000,7 @@ struct text_event te[] = {
 	 N_("-%C10-%C11-%O$tConnected. Now logging in.."), 0, NULL},
 	{"Stop Connection", pevt_sconnect_help,
 	 N_("-%C10-%C11-%O$tStopped previous connection attempt (pid=$1)"), 1, NULL},
-	{"Disconnected", pevt_generic_none_help,
+	{"Disconnected", pevt_discon_help,
 	 N_("-%C10-%C11-%O$tDisconnected ($1)."), 1, NULL},
 	{"No DCC", pevt_generic_none_help, N_("-%C10-%C11-%O$tNo such DCC."), 0, NULL},
 	
