@@ -947,7 +947,7 @@ country (char *hostname)
 	char *p;
 	int i;
 	if (!hostname || !*hostname || isdigit (hostname[strlen (hostname) - 1]))
-		return _("unknown");
+		return _("Unknown");
 	if ((p = strrchr (hostname, '.')))
 		p++;
 	else
@@ -955,7 +955,7 @@ country (char *hostname)
 	for (i = 0; domain[i].code; i++)
 		if (!strcasecmp (p, domain[i].code))
 			return domain[i].country;
-	return _("unknown");
+	return _("Unknown");
 }
 
 /* I think gnome1.0.x isn't necessarily linked against popt, ah well! */
