@@ -143,8 +143,8 @@ tcp_send_real (struct server *serv, char *buf, int len)
 static int
 tcp_send_queue (struct server *serv)
 {
-	char *buf, *p, pri;
-	int len, i;
+	char *buf, *p;
+	int len, i, pri;
 	GSList *list;
 	time_t now = time (0);
 
@@ -838,7 +838,7 @@ save_away_message (struct server *serv, char *nick, char *msg)
 	"NAME TIME\n"				"CMD /nctcp %s TIME %t\n\n"\
 	"NAME PING\n"				"CMD /nctcp %s PING %d\n\n"
 
-#define defaultconf_popup \
+#define defaultconf_popup _( \
 	"NAME SUB\n"				"CMD Direct Client-To-Client\n\n"\
 	"NAME Send File\n"		"CMD /dcc send %s\n\n"\
 	"NAME Offer Chat\n"		"CMD /dcc chat %s\n\n"\
@@ -894,22 +894,22 @@ save_away_message (struct server *serv, char *nick, char *msg)
 	"NAME Ping\n"				"CMD !rxvt -e /bin/sh -c \"ping -c 4 %h ; sleep 30\"\n\n"\
 	"NAME Telnet\n"			"CMD !rxvt -e telnet %h\n\n"\
 	"NAME ENDSUB\n"			"CMD \n\n"\
-	"NAME Open Query\n"		"CMD /query %s\n\n"
+	"NAME Open Query\n"		"CMD /query %s\n\n")
 
-#define defaultconf_buttons \
+#define defaultconf_buttons _( \
 	"NAME Op\n"					"CMD /op %a\n\n"\
 	"NAME DeOp\n"				"CMD /deop %a\n\n"\
 	"NAME Ban\n"				"CMD /ban %s\n\n"\
 	"NAME Kick\n"				"CMD /kick %s\n\n"\
 	"NAME Sendfile\n"			"CMD /dcc send %s\n\n"\
-	"NAME Dialog\n"			"CMD /query %s\n\n"
+	"NAME Dialog\n"			"CMD /query %s\n\n")
 
-#define defaultconf_dlgbuttons \
+#define defaultconf_dlgbuttons _( \
 	"NAME Whois\n"				"CMD /whois %s\n\n"\
 	"NAME Send\n"				"CMD /dcc send %s\n\n"\
 	"NAME Chat\n"				"CMD /dcc chat %s\n\n"\
 	"NAME Ping\n"				"CMD /ping %s\n\n"\
-	"NAME Clear\n"				"CMD /clear\n\n"\
+	"NAME Clear\n"				"CMD /clear\n\n")
 
 #define defaultconf_replace \
 	"NAME teh\n"				"CMD the\n\n"\
@@ -943,7 +943,7 @@ save_away_message (struct server *serv, char *nick, char *msg)
    "NAME WALLOPS\n"		"CMD /quote WALLOPS :&2\n\n"\
    "NAME WII\n"			"CMD /quote WHOIS %2 %2\n\n"
 
-#define defaultconf_usermenu \
+#define defaultconf_usermenu _( \
 	"NAME SUB\n"					"CMD IRC Stuff\n\n"\
    "NAME Disconnect\n"			"CMD /discon\n\n"\
    "NAME Reconnect\n"			"CMD /reconnect\n\n"\
@@ -970,14 +970,14 @@ save_away_message (struct server *serv, char *nick, char *msg)
 	"NAME SUB\n"					"CMD External\n\n"\
    "NAME Run XMMS\n"				"CMD !xmms\n\n"\
 	"NAME Run RXVT\n"				"CMD !rxvt\n\n"\
-   "NAME ENDSUB\n"				"CMD \n\n"
+   "NAME ENDSUB\n"				"CMD \n\n")
 
 #ifdef WIN32
 #define defaultconf_urlhandlers \
 	"NAME Open URL\n"							"CMD !start %s\n\n"\
 	"NAME Connect as IRC server\n"		"CMD /newserver %s\n\n"
 #else
-#define defaultconf_urlhandlers \
+#define defaultconf_urlhandlers _( \
 	"NAME SUB\n"								"CMD Netscape...\n\n"\
    	"NAME Open in existing\n"			"CMD !netscape -remote 'openURL(%s)'\n\n"\
    	"NAME Open in new window\n"		"CMD !netscape -remote 'openURL(%s,new-window)'\n\n"\
@@ -1006,11 +1006,11 @@ save_away_message (struct server *serv, char *nick, char *msg)
    	"NAME w3m\n"							"CMD !rxvt -e w3m %s\n\n"\
    	"NAME NcFTP\n" 						"CMD !rxvt -e ncftp %s\n\n"\
    	"NAME gFTP\n"							"CMD !gftp %s\n\n"\
-		"NAME KFM\n"							"CMD !kfmclient openURL %s\n\n"\
+		"NAME Konqueror\n"					"CMD !konqueror %s\n\n"\
 		"NAME Telnet\n"						"CMD !rxvt -e telnet %s\n\n"\
 		"NAME Ping\n"							"CMD !rxvt -e ping -c 4 %s\n\n"\
 	"NAME ENDSUB\n"							"CMD \n\n"\
-	"NAME Connect as IRC server\n"		"CMD /newserver %s\n\n"
+	"NAME Connect as IRC server\n"		"CMD /newserver %s\n\n")
 #endif
 
 static void
