@@ -201,10 +201,12 @@ struct xchatprefs
 	unsigned int timestamp;
 	unsigned int fastdccsend;
 	unsigned int dcc_send_fillspaces;
+	unsigned int dcc_remove;
 	unsigned int skipserverlist;
 	unsigned int filterbeep;
 	unsigned int beepmsg;
 	unsigned int beepchans;
+	unsigned int truncchans;
 	unsigned int privmsgtab;
 	unsigned int logging;
 	unsigned int timestamp_logs;
@@ -218,6 +220,7 @@ struct xchatprefs
 	unsigned int raw_modes;
 	unsigned int show_away_once;
 	unsigned int show_away_message;
+	unsigned int auto_unmark_away;
 	unsigned int userhost;
 	unsigned int use_server_tab;
 	unsigned int notices_tabs;
@@ -351,6 +354,7 @@ struct server
 	char *nick_prefixes;				/* e.g. "*@%+" */
 	char *nick_modes;					/* e.g. "aohv" */
 	char *bad_nick_prefixes;		/* for ircd that doesn't give the modes */
+	int modes_per_line;				/* 6 on undernet, 4 on efnet etc... */
 
 	char *eom_cmd;						/* end-of-motd command, free it! */
 
@@ -383,7 +387,6 @@ struct server
 	int end_of_motd:1;			  /* end of motd reached (logged in) */
 	int sent_quit:1;				  /* sent a QUIT already? */
 	int is_newtype:1;		/* undernet and dalnet need /list >0,<10000 */
-	int six_modes:1;		/* undernet allows 6 modes per line */
 	int is_away:1;
 	int reconnect_away:1;		/* whether to reconnect in is_away state */
 	int dont_use_proxy:1;		/* to proxy or not to proxy */
