@@ -18,25 +18,40 @@
 
 #include <stdio.h>
 #include <stdlib.h>
-#include "../common/xchat.h"
+#include <string.h>
 #include "fe-gtk.h"
+#include "../common/xchat.h"
+#include "../common/util.h"
+#include "palette.h"
 #include "gtkutil.h"
+#ifdef USE_XLIB
+#include <gdk/gdkx.h>
+#endif
+#include "about.h"
 
-extern GdkColor colors[];
 
 #ifdef USE_GNOME
 
 void
 menu_about (GtkWidget * wid, gpointer sess)
 {
+	char buf[512];
 	const gchar *author[] = { "Peter Zelezny <zed@linux.com>", 0 };
 
-	gtk_widget_show (gnome_about_new ("X-Chat",
-							VERSION,
-							"(C) 1998-2000 Peter Zelezny",
-							author,
-							"Visit the X-Chat webpage http://xchat.org",
-							0));
+	snprintf (buf, sizeof (buf),
+				 _("An IRC Client for UNIX.\n\n"
+				 "This binary was compiled on "__DATE__"\n"
+				 "Using GTK %d.%d.%d X %d\n"
+				 "Running on %s"),
+				 gtk_major_version, gtk_minor_version, gtk_micro_version,
+#ifdef USE_XLIB
+				VendorRelease (GDK_DISPLAY ()), get_cpu_str());
+#else
+				666, get_cpu_str());
+#endif
+
+	gtk_widget_show (gnome_about_new ("X-Chat", VERSION,
+							"(C) 1998-2001 Peter Zelezny", author, buf, 0));
 }
 
 #else
@@ -56,6 +71,7 @@ menu_about (GtkWidget * wid, gpointer sess)
 	GtkWidget *vbox, *label, *hbox;
 	GtkStyle *about_style;
 	GtkStyle *head_style;
+	char buf[512];
 
 	if (about)
 	{
@@ -63,10 +79,12 @@ menu_about (GtkWidget * wid, gpointer sess)
 		return;
 	}
 	head_style = gtk_style_new ();
+#ifndef WIN32
 	gdk_font_unref (head_style->font);
 	head_style->font = gdk_font_load ("-*-times-bold-i-*-*-*-240-*");
 	if (!head_style->font)
 		head_style->font = gdk_font_load ("fixed");
+#endif
 	head_style->fg[GTK_STATE_NORMAL] = colors[2];
 
 	about_style = gtk_style_new ();
@@ -75,7 +93,7 @@ menu_about (GtkWidget * wid, gpointer sess)
 
 	about = gtk_window_new (GTK_WINDOW_DIALOG);
 	gtk_window_position (GTK_WINDOW (about), GTK_WIN_POS_CENTER);
-	gtk_window_set_title (GTK_WINDOW (about), "About X-Chat");
+	gtk_window_set_title (GTK_WINDOW (about), _("About X-Chat"));
 	gtk_container_set_border_width (GTK_CONTAINER (about), 6);
 	gtk_signal_connect (GTK_OBJECT (about), "destroy",
 							  GTK_SIGNAL_FUNC (about_close), 0);
@@ -92,10 +110,20 @@ menu_about (GtkWidget * wid, gpointer sess)
 	gtk_style_unref (head_style);
 	gtk_container_add (GTK_CONTAINER (vbox), label);
 
-	label = gtk_label_new (	"\n"
-									"(C) 1998-2000 Peter Zelezny\n"
-									"Author:   Peter Zelezny <zed@linux.com>\n\n"
-									"Visit the X-Chat webpage http://xchat.org\n");
+	snprintf (buf, sizeof (buf),
+				 _("(C) 1998-2001 Peter Zelezny <zed@linux.com>\n\n"
+				 "An IRC Client for UNIX.\n\n"
+				 "This binary was compiled on "__DATE__"\n"
+				 "Using GTK %d.%d.%d X %d\n"
+				 "Running on %s\n"),
+				 gtk_major_version, gtk_minor_version, gtk_micro_version,
+#ifdef USE_XLIB
+				VendorRelease (GDK_DISPLAY ()), get_cpu_str());
+#else
+				666, get_cpu_str());
+#endif
+
+	label = gtk_label_new (buf);
 	gtk_container_add (GTK_CONTAINER (vbox), label);
 	gtk_widget_set_style (label, about_style);
 	gtk_style_unref (about_style);
