@@ -31,16 +31,13 @@ static void
 ascii_click (GtkWidget * wid, int c)
 {
 	int tmp_pos;
-	unsigned char str[2];
-
-	str[0] = c;
-	str[1] = 0;
+	unsigned char str = c;
 
 	if (menu_sess)
 	{
 		wid = menu_sess->gui->inputgad;
 		tmp_pos = gtk_editable_get_position (GTK_EDITABLE (wid));
-		gtk_editable_insert_text (GTK_EDITABLE (wid), str, 2, &tmp_pos);
+		gtk_editable_insert_text (GTK_EDITABLE (wid), &str, 1, &tmp_pos);
 		gtk_entry_set_position (GTK_ENTRY (wid), tmp_pos);
 	}
 }
