@@ -87,25 +87,29 @@ banlist_refresh (GtkWidget * wid, struct session *sess)
 static void
 banlist_unban (GtkWidget * wid, struct session *sess)
 {
-	char tbuf[2048], *mask;
-	unsigned int i;
-	unsigned int sel_length =
-		g_list_length (GTK_CLIST (sess->gui->banlist_clistBan)->selection);
+	char tbuf[2048];
+	unsigned int sel_length;
 	char **masks;
-	int row;
+	int i, row;
+	GList *list;
+
+	/* grab the list of selected items */
+	list = GTK_CLIST (sess->gui->banlist_clistBan)->selection;
+	sel_length = g_list_length (list);
 
 	if (sel_length < 1)
 		return;
 
 	/* create an array of all the masks */
 	masks = malloc (sel_length * sizeof (char *));
-	for (i = 0; i < sel_length; i++)
+	i = 0;
+	while (list)
 	{
-		row = (int)g_list_nth_data (GTK_CLIST (sess->gui->banlist_clistBan)->
-											 selection, i);
+		row = (int) list->data;
 		gtk_clist_get_text (GTK_CLIST (sess->gui->banlist_clistBan), row, 0,
-								  &mask);
-		masks[i] = mask;
+								  &masks[i]);
+		i++;
+		list = list->next;
 	}
 
 	send_channel_modes (sess, tbuf, masks, 0, i, '-', 'b');
