@@ -24,13 +24,29 @@
 #endif
 #include <stdlib.h>
 #include <unistd.h>
+
+#include "fe-gtk.h"
 #include "../common/xchat.h"
 #include "../common/fe.h"
 #include "../common/util.h"
-#include "fe-gtk.h"
+#include "../common/text.h"
+#include "../common/cfgfiles.h"
+#include "../common/xchatc.h"
 #include "gtkutil.h"
+#include "maingui.h"
 #include "pixmaps.h"
 #include "xtext.h"
+#include "palette.h"
+#include "menu.h"
+#include "notifygui.h"
+#include "textgui.h"
+#include "fkeys.h"
+#include "urlgrab.h"
+
+#ifdef USE_PANEL
+#include "panel.h"
+#include <applet-widget.h>
+#endif
 
 #ifdef USE_XLIB
 #include <gdk/gdkx.h>
@@ -41,54 +57,22 @@
 #include <gdk-pixbuf/gdk-pixbuf.h>
 #endif
 
-#ifdef USE_PANEL
-#include <applet-widget.h>
-extern int nopanel;
-#endif
-
 GdkFont *font_normal;
 GdkFont *dialog_font_normal;
-
-GtkWidget *proxy_invisible;
-
-extern GtkStyle *redtab_style;
-extern GtkStyle *bluetab_style;
-extern GtkStyle *inputgad_style;
 GdkPixmap *channelwin_pix;
 GdkPixmap *dialogwin_pix;
 
-extern int auto_connect;
-extern char *xdir;
-extern struct session *current_tab;
-extern struct xchatprefs prefs;
-extern GSList *sess_list;
-extern GSList *serv_list;
-extern GdkColor colors[];
 
-extern int is_session (session * sess);
-extern char *get_cpu_str (int color);
-extern void userlist_hide (GtkWidget * igad, struct session *sess);
-extern void PrintTextRaw (GtkWidget * textwidget, unsigned char *text, int indent);
-extern void notify_gui_update (void);
-extern void update_all_of (char *name);
-extern void palette_load (void);
-extern void palette_save (void);
-extern void key_init (void);
-extern void create_window (struct session *);
-extern void PrintText (struct session *, char *);
-extern void url_autosave (void);
 extern void open_server_list (GtkWidget *wid, gpointer sess, int dontshow);
 extern void serverlist_autoconnect (struct session *sess, int);
-extern void tree_blue_style (struct session *);
-extern void tree_red_style (struct session *);
-extern void menu_newshell_set_palette (session *sess);
+
 
 #ifdef USE_XLIB
 
-extern Window get_desktop_window (Window the_window);
+static GtkWidget *proxy_invisible;
 
-
-static void redraw_trans_xtexts (void)
+static void
+redraw_trans_xtexts (void)
 {
 	GSList *list = sess_list;
 	struct session *sess;
@@ -96,7 +80,7 @@ static void redraw_trans_xtexts (void)
 	{
 		sess = (struct session *) list->data;
 #ifdef USE_ZVT
-		if (sess->is_shell)
+		if (sess->type == SESS_SHELL)
 		{
 			menu_newshell_set_palette (sess);
 			gtk_widget_queue_draw (sess->gui->textgad);
@@ -108,9 +92,9 @@ static void redraw_trans_xtexts (void)
 	}
 }
 
-static gboolean handle_property_notify (GtkWidget *widget,
-										GdkEventProperty *event,
-										gpointer user_data)
+static gboolean
+handle_property_notify (GtkWidget *widget, GdkEventProperty *event,
+								gpointer user_data)
 {
 	static Atom prop = None;
 
@@ -130,10 +114,10 @@ fe_args (int argc, char *argv[])
 {
 #ifdef USE_GNOME
 	struct poptOption options[] = {
-		{"cfgdir", 'd', POPT_ARG_STRING, 0, 0, "Config dir", 0},
-		{"noauto", 'a', POPT_ARG_NONE, 0, 0, "Don't Auto connect", 0},
+		{"cfgdir", 'd', POPT_ARG_STRING, 0, 0, _("Config dir"), 0},
+		{"noauto", 'a', POPT_ARG_NONE, 0, 0, _("Don't Auto connect"), 0},
 #ifdef USE_PANEL
-		{"no-panel", 'n', POPT_ARG_NONE, 0, 0, "Don't use GNOME Panel", 0},
+		{"no-panel", 'n', POPT_ARG_NONE, 0, 0, _("Don't use GNOME Panel"), 0},
 #endif
 		POPT_AUTOHELP {0, '\0', 0, 0}
 	};
@@ -153,7 +137,7 @@ fe_args (int argc, char *argv[])
 #endif
 		if (!strcasecmp (argv[1], "-v") || !strcasecmp (argv[1], "--version"))
 		{
-			puts (PACKAGE" "VERSION);
+			printf (PACKAGE" "VERSION"\n");
 			return 0;
 		}
 #ifndef USE_GNOME
@@ -163,10 +147,11 @@ fe_args (int argc, char *argv[])
 #endif
 		if (!strcasecmp (argv[1], "-h") || !strcasecmp (argv[1], "--help"))
 		{
-			puts (PACKAGE" "VERSION" Options:\n\n"
+			printf(_("%s %s Options:\n\n"
 					"   --cfgdir <dir> -d\t : use a different config dir\n"
 					"   --noauto       -a\t : don't auto connect\n"
-					"   --version      -v\t : show version information\n");
+					"   --version      -v\t : show version information\n"
+                ), PACKAGE, VERSION);
 			return 0;
 		}
 #endif
@@ -195,8 +180,15 @@ fe_args (int argc, char *argv[])
 #ifdef USE_PANEL
 	if (nopanel)
 		gnome_init_with_popt_table (argv[0], VERSION, argc, argv, options, 0, 0);
-	else
-		applet_widget_init (argv[0], VERSION, argc, argv, options, 0, 0);
+	else {
+		CORBA_Environment ev;
+		CORBA_exception_init (&ev);
+
+		gnome_CORBA_init_with_popt_table (argv[0], VERSION,
+						  &argc, argv, options, 0, 0,
+						  GNORBA_INIT_SERVER_FUNC, &ev);
+		CORBA_exception_free (&ev);
+	}
 #else
 #ifdef USE_GNOME
 	gnome_init_with_popt_table (argv[0], VERSION, argc, argv, options, 0, 0);
@@ -221,7 +213,8 @@ fe_args (int argc, char *argv[])
 	/* Select for PropertyNotify events from the root window */
 	XSelectInput (GDK_DISPLAY (), GDK_ROOT_WINDOW (), PropertyChangeMask);
 
-	gtk_signal_connect(GTK_OBJECT(proxy_invisible), "property-notify-event", GTK_SIGNAL_FUNC(handle_property_notify), NULL);
+	gtk_signal_connect (GTK_OBJECT (proxy_invisible), "property-notify-event",
+							 GTK_SIGNAL_FUNC (handle_property_notify), NULL);
 #endif
 
 	return 1;
@@ -241,19 +234,19 @@ my_font_load (char *fontname)
 		font = gdk_font_load (fontname);
 	if (!font)
 	{
-		snprintf (temp, 255, "Cannot open font:\n\n%s", fontname);
+		snprintf (temp, sizeof (temp), _("Cannot open font:\n\n%s"), fontname);
 		gtkutil_simpledialog (temp);
 		font = gdk_font_load ("fixed");
 		if (!font)
 		{
-			g_error ("gdk_font_load failed");
+			g_error (_("gdk_font_load failed"));
 			gtk_exit (0);
 		}
 	}
 	return font;
 }
 
-static GtkStyle *
+GtkStyle *
 create_inputgad_style (void)
 {
 	GtkStyle *style;
@@ -281,100 +274,11 @@ fe_init (void)
 	key_init ();
 	pixmaps_init ();
 
-	channelwin_pix = pixmap_load_from_file_with_msg (prefs.background);
-	dialogwin_pix = pixmap_load_from_file_with_msg (prefs.background_dialog);
+	channelwin_pix = pixmap_load_from_file (prefs.background);
+	dialogwin_pix = pixmap_load_from_file (prefs.background_dialog);
 	inputgad_style = create_inputgad_style ();
 }
 
-static int done_intro = 0;
-
-static void
-init_sess (void)
-{
-	char buf[512];
-	struct session *sess = sess_list->data;
-
-	if (done_intro)
-		return;
-	done_intro = 1;
-
-	if (auto_connect)
-	{
-		open_server_list (0, sess, prefs.skipserverlist);
-		serverlist_autoconnect (sess, prefs.skipserverlist);
-	} else
-	{
-		if (!prefs.skipserverlist)
-			open_server_list (0, sess, 0);
-	}
-
-	snprintf (buf, sizeof (buf),	
-   	"\n"
-		"\00314-\00315-\00301-\00310-\00311 xchat "VERSION""
-		" \00310-\00301-\00315-\00314-\017\n"
-		"\n"
-		"\00314[ \0036 system  \00314] \017 %s\n"
-		"\00314[ \0036  gui    \00314] \017 X %d GTK %d.%d.%d\n"
-		"\00314[ \0036nickname \00314] \017 %s\n"
-		"\00314[ \0036compiled \00314] \017 "__DATE__"\n",
-				get_cpu_str (1),
-#ifdef USE_XLIB
-				VendorRelease (GDK_DISPLAY ()),
-#else
-				666,
-#endif
-				gtk_major_version, gtk_minor_version, gtk_micro_version,
-				prefs.nick1
-				);
-	PrintText (sess, buf);
-
-	strcpy (buf, "\00314[ \0036features \00314] \017 ");
-#ifdef USE_GDK_PIXBUF
-	strcat (buf, "Gdk-Pixbuf ");
-#endif
-#ifdef USE_GNOME
-	strcat (buf, "Gnome ");
-#endif
-#ifdef USE_ZVT
-	strcat (buf, "Zvt ");
-#endif
-#ifdef USE_PANEL
-	strcat (buf, "Panel ");
-#endif
-#ifdef USE_PERL
-	strcat (buf, "Perl ");
-#endif
-#ifdef USE_PYTHON
-	strcat (buf, "Python ");
-#endif
-#ifdef USE_PLUGIN
-	strcat (buf, "Plugin ");
-#endif
-#ifdef ENABLE_NLS
-	strcat (buf, "NLS ");
-#endif
-#ifdef USE_TRANS
-	strcat (buf, "Trans ");
-#endif
-#ifdef USE_HEBREW
-	strcat (buf, "Hebrew ");
-#endif
-#ifdef USE_OPENSSL
-	strcat (buf, "OpenSSL ");
-#endif
-#ifdef SOCKS
-	strcat (buf, "Socks5\n\n");
-#else
-	strcat (buf, "\n\n");
-#endif
-	PrintText (sess, buf);
-
-	PrintText (sess, "\n\0033*\00315 Type \017/help\00315 for a list of commands\017\n\n");
-
-	while (gtk_events_pending ())
-		gtk_main_iteration ();
-}
-
 void
 fe_main (void)
 {
@@ -386,6 +290,10 @@ fe_main (void)
 #else
 	gtk_main ();
 #endif
+
+	/* sleep for 3 seconds so any QUIT messages are not lost. The  */
+	/* GUI is closed at this point, so the user doesn't even know! */
+	sleep (3);
 }
 
 void
@@ -395,6 +303,10 @@ fe_cleanup (void)
 
 	if (prefs.autosave_url)
 		url_autosave ();
+
+#ifdef USE_PANEL
+	panel_cleanup ();
+#endif
 }
 
 void
@@ -406,13 +318,13 @@ fe_exit (void)
 int
 fe_timeout_add (int interval, void *callback, void *userdata)
 {
-	return gtk_timeout_add (interval, (GtkFunction) callback, userdata);
+	return g_timeout_add (interval, (GSourceFunc) callback, userdata);
 }
 
 void
 fe_timeout_remove (int tag)
 {
-	gtk_timeout_remove (tag);
+	g_source_remove (tag);
 }
 
 void
@@ -421,7 +333,6 @@ fe_new_window (struct session *sess)
 	sess->gui = malloc (sizeof (struct session_gui));
 	memset (sess->gui, 0, sizeof (struct session_gui));
 	create_window (sess);
-	init_sess ();
 }
 
 void
@@ -431,6 +342,12 @@ fe_new_server (struct server *serv)
 	memset (serv->gui, 0, sizeof (struct server_gui));
 }
 
+static void
+null_this_var (GtkWidget * unused, GtkWidget ** dialog)
+{
+	*dialog = 0;
+}
+
 void
 fe_message (char *msg, int wait)
 {
@@ -440,7 +357,7 @@ fe_message (char *msg, int wait)
 	if (wait)
 	{
 		gtk_signal_connect (GTK_OBJECT (dialog), "destroy",
-								  gtkutil_null_this_var, &dialog);
+								  null_this_var, &dialog);
 		while (dialog)
 			gtk_main_iteration ();
 	}
@@ -449,28 +366,50 @@ fe_message (char *msg, int wait)
 void
 fe_input_remove (int tag)
 {
-	gdk_input_remove (tag);
+	g_source_remove (tag);
 }
 
 int
 fe_input_add (int sok, int read, int write, int ex, void *func, void *data)
 {
-	int type = 0;
+	int tag, type = 0;
+	GIOChannel *channel;
+
+#ifdef WIN32
+	if (read == 3)
+		channel = g_io_channel_win32_new_fd (sok);
+	else
+		channel = g_io_channel_win32_new_socket (sok);
+#else
+	channel = g_io_channel_unix_new (sok);
+#endif
 
 	if (read)
-		type |= GDK_INPUT_READ;
+		type |= G_IO_IN | G_IO_HUP | G_IO_ERR;
 	if (write)
-		type |= GDK_INPUT_WRITE;
+		type |= G_IO_OUT | G_IO_ERR;
 	if (ex)
-		type |= GDK_INPUT_EXCEPTION;
+		type |= G_IO_PRI;
 
-	return gdk_input_add (sok, type, func, data);
+	tag = g_io_add_watch (channel, type, (GIOFunc) func, data);
+	g_io_channel_unref (channel);
+
+	return tag;
 }
 
 void
 fe_set_topic (struct session *sess, char *topic)
 {
+	char buf[512];
+
 	gtk_entry_set_text (GTK_ENTRY (sess->gui->topicgad), topic);
+
+	if (sess->type == SESS_CHANNEL)
+	{
+		snprintf (buf, sizeof (buf), _("Topic for %s is: %s"), sess->channel,
+					 topic);
+		add_tip (sess->gui->topicgad, buf);
+	}
 }
 
 void
@@ -514,6 +453,14 @@ fe_is_chanwindow (struct server *serv)
 	return 1;
 }
 
+int
+fe_is_banwindow (struct session *sess)
+{
+   if (!sess->gui->banlist_window)
+     return 0;
+   return 1;
+}
+
 void
 fe_chan_list_end (struct server *serv)
 {
@@ -532,10 +479,7 @@ fe_notify_update (char *name)
 void
 fe_text_clear (struct session *sess)
 {
-	GtkXText *xtext = (GtkXText *)sess->gui->textgad;
-	gtk_xtext_clear (xtext);
-	if (xtext->auto_indent)
-		xtext->indent = 1;
+	gtk_xtext_clear (GTK_XTEXT (sess->gui->textgad));
 }
 
 void
@@ -582,8 +526,7 @@ fe_progressbar_start (struct session *sess)
 		gtk_box_pack_start (GTK_BOX (sess->gui->op_box), sess->gui->bar, 0, 0,
 								  0);
 		gtk_widget_show (sess->gui->bar);
-		sess->server->bartag =
-			gtk_timeout_add (50, (GtkFunction) updatedate_bar, sess);
+		sess->server->bartag = fe_timeout_add (50, updatedate_bar, sess);
 	}
 }
 
@@ -605,7 +548,7 @@ fe_progressbar_end (struct session *sess)
 				if (GTK_IS_WIDGET (sess->gui->bar))
 					gtk_widget_destroy (sess->gui->bar);
 				sess->gui->bar = 0;
-				gtk_timeout_remove (sess->server->bartag);
+				fe_timeout_remove (sess->server->bartag);
 			}
 			list = list->next;
 		}
@@ -617,7 +560,7 @@ fe_print_text (struct session *sess, char *text)
 {
 	int indent;
 
-	if (sess->is_dialog)
+	if (sess->type == SESS_DIALOG)
 		indent = prefs.dialog_indent_nicks;
 	else
 		indent = prefs.indent_nicks;
@@ -655,6 +598,14 @@ fe_beep (void)
 	gdk_beep ();
 }
 
+int
+fe_is_beep (struct session *sess)
+{
+	if (GTK_TOGGLE_BUTTON (sess->gui->beepbutton)->active)
+		return 1;
+	return 0;
+}
+
 int
 fe_is_confmode (struct session *sess)
 {
@@ -663,12 +614,6 @@ fe_is_confmode (struct session *sess)
 	return 0;
 }
 
-void
-fe_userlist_hide (struct session *sess)
-{
-	userlist_hide (0, sess);
-}
-
 void
 fe_lastlog (session *sess, session *lastlog_sess, char *sstr)
 {
@@ -696,6 +641,16 @@ fe_set_lag (server *serv, int lag)
 	GSList *list = sess_list;
 	session *sess;
 	gdouble per;
+	char tip[64];
+	unsigned long nowtim;
+
+	if (lag == -1)
+	{
+		if (!serv->lag_sent)
+			return;
+		nowtim = make_ping_time ();
+		lag = (nowtim - serv->lag_sent) / 100000;
+	}
 
 	per = (double)((double)lag / (double)40);
 	if (per > 1.0)
@@ -704,10 +659,51 @@ fe_set_lag (server *serv, int lag)
 	while (list)
 	{
 		sess = list->data;
-		if (sess->server == serv && sess->gui->lagometer)
+		if (sess->server == serv)
 		{
-			gtk_progress_bar_update ((GtkProgressBar *) sess->gui->lagometer, per);
+			if (sess->gui->lagometer)
+			{
+				gtk_progress_bar_update ((GtkProgressBar *) sess->gui->lagometer, per);
+			}
+			if (sess->gui->laginfo)
+			{
+				snprintf (tip, sizeof(tip) - 1, "%s%d.%ds",
+					serv->lag_sent ? "+" : "", lag / 10, lag % 10);
+				gtk_label_set_text ((GtkLabel *) sess->gui->laginfo, tip);
+			}
 		}
 		list = list->next;
 	}
 }
+
+void
+fe_set_throttle (server *serv)
+{
+	GSList *list = sess_list;
+	struct session *sess;
+	float per;
+	char tbuf[64];
+
+	per = (float) serv->sendq_len / 1024.0;
+	if (per > 1.0)
+		per = 1.0;
+
+	while (list)
+	{
+		sess = list->data;
+		if (sess->server == serv)
+		{
+			if (sess->gui->throttlemeter)
+			{
+				gtk_progress_bar_update ((GtkProgressBar *) sess->gui->throttlemeter, per);
+			}
+			if (sess->gui->throttleinfo)
+			{
+				snprintf (tbuf, sizeof(tbuf) - 1, "%d bytes", serv->sendq_len);
+				gtk_label_set_text ((GtkLabel *) sess->gui->throttleinfo, tbuf);
+			}
+		}
+		list = list->next;
+	}
+}
+
