@@ -1,11 +1,13 @@
-#ifndef SKIPCONFIG
 #include "../../config.h"
-#endif
 
+#ifndef WIN32
+#include <sys/types.h>
 #include <regex.h>
+#endif
 
 #ifdef USE_GNOME
 
+#undef _
 #include <gnome.h>
 #undef GNOME_APP
 #define GNOME_APP(n) ((GnomeApp*)n)
@@ -14,7 +16,7 @@
 
 #include <gtk/gtk.h>
 #include "fake_gnome.h"
-#ifdef ENABLE_NLS
+#if defined(ENABLE_NLS) && !defined(_)
 #  include <libintl.h>
 #  define _(x) gettext(x)
 #  ifdef gettext_noop
@@ -22,7 +24,9 @@
 #  else
 #    define N_(String) (String)
 #  endif
-#else
+#endif
+#if !defined(ENABLE_NLS) && defined(_)
+#  undef _
 #  define N_(String) (String)
 #  define _(x) (x)
 #endif
@@ -50,8 +54,16 @@
 #undef GTK_TOGGLE_BUTTON
 #undef GTK_NOTEBOOK
 #undef GTK_MENU_ITEM
+#undef GTK_OPTION_MENU
+#undef GTK_MENU
 #undef GTK_CTREE
 #undef GTK_COLOR_SELECTION_DIALOG
+#undef GTK_EDITABLE
+#undef GTK_RANGE
+#undef GTK_CHECK_MENU_ITEM
+#undef GTK_MISC
+#undef GTK_FRAME
+#undef GTK_BUTTON_BOX
 
 #define GTK_BIN(n) ((GtkBin *)n)
 #define GTK_WINDOW(n) ((GtkWindow *)n)
@@ -74,8 +86,16 @@
 #define GTK_TOGGLE_BUTTON(n) ((GtkToggleButton *)n)
 #define GTK_NOTEBOOK(n) ((GtkNotebook*)n)
 #define GTK_MENU_ITEM(n) ((GtkMenuItem*)n)
+#define GTK_OPTION_MENU(n) ((GtkOptionMenu *)n)
+#define GTK_MENU(n) ((GtkMenu *)n)
 #define GTK_CTREE(n) ((GtkCTree*)n)
 #define GTK_COLOR_SELECTION_DIALOG(n) ((GtkColorSelectionDialog *)n)
+#define GTK_EDITABLE(n) ((GtkEditable *)n)
+#define GTK_RANGE(n) ((GtkRange *)n)
+#define GTK_CHECK_MENU_ITEM(n) ((GtkCheckMenuItem *)n)
+#define GTK_MISC(n) ((GtkMisc *)n)
+#define GTK_FRAME(n) ((GtkFrame *)n)
+#define GTK_BUTTON_BOX(n) ((GtkButtonBox *)n)
 
 #define flag_t flag_wid[0]
 #define flag_n flag_wid[1]
@@ -85,6 +105,8 @@
 #define flag_m flag_wid[5]
 #define flag_l flag_wid[6]
 #define flag_k flag_wid[7]
+#define flag_b flag_wid[8]
+#define NUM_FLAG_WIDS 9
 
 struct server_gui
 {
@@ -105,7 +127,11 @@ struct server_gui
 	gboolean chanlist_match_wants_channel;	/* match in channel name */
 	gboolean chanlist_match_wants_topic;	/* match in topic */
 
+#ifndef WIN32
 	regex_t chanlist_match_regex;	/* compiled regular expression here */
+#else
+	char *chanlist_match_regex;
+#endif
 
 	guint chanlist_users_found_count;	/* users total for all channels */
 	guint chanlist_users_shown_count;	/* users total for displayed channels */
@@ -146,16 +172,30 @@ struct session_gui
 	GtkWidget *nl_box;
 	GtkWidget *button_box;
 	GtkWidget *toolbox;
+	GtkWidget *laginfo;
+	GtkWidget *throttleinfo;
 	GtkWidget *lagometer;
+	GtkWidget *throttlemeter;
 	GtkWidget *bar;
 	GtkWidget *leftpane;
 	GtkWidget *confbutton;		  /* conference mode button */
-	GtkWidget *flag_wid[8];
+	GtkWidget *beepbutton;
+	GtkWidget *flag_wid[NUM_FLAG_WIDS];
 	GtkWidget *limit_entry;		  /* +l */
 	GtkWidget *key_entry;		  /* +k */
-	GtkWidget *tableft_button;
-	GtkWidget *tabright_button;
 #ifdef USE_PANEL
 	GtkWidget *panel_button;
 #endif
+
+	/* banlist stuff */
+	GtkWidget *banlist_window;
+	GtkWidget *banlist_clistBan;
+	GtkWidget *banlist_butRefresh;
 };
+
+GdkFont *my_font_load (char *fontname);
+
+extern GdkFont *font_normal;
+extern GdkFont *dialog_font_normal;
+extern GdkPixmap *channelwin_pix;
+extern GdkPixmap *dialogwin_pix;
