@@ -324,34 +324,34 @@ static GtkWidget *key_dialog_text;
 static void
 key_load_defaults ()
 {
-	char def[] =
 		/* This is the default config */
-		"A\nminus\nChange Page\nD1:-1\nD2:Relative\n\n"
-		"A\n9\nChange Page\nD1:9\nD2!\n\n"
-		"A\n8\nChange Page\nD1:8\nD2!\n\n"
-		"A\n7\nChange Page\nD1:7\nD2!\n\n"
-		"A\n6\nChange Page\nD1:6\nD2!\n\n"
-		"A\n5\nChange Page\nD1:5\nD2!\n\n"
-		"A\n4\nChange Page\nD1:4\nD2!\n\n"
-		"A\n3\nChange Page\nD1:3\nD2!\n\n"
-		"A\n2\nChange Page\nD1:2\nD2!\n\n"
-		"A\n1\nChange Page\nD1:1\nD2!\n\n"
-		"C\no\nInsert in Buffer\nD1:%O\nD2!\n\n"
-		"C\nb\nInsert in Buffer\nD1:%B\nD2!\n\n"
-		"C\nk\nInsert in Buffer\nD1:%C\nD2!\n\n"
-		"S\nNext\nChange Selected Nick\nD1!\nD2!\n\n"
-		"S\nPrior\nChange Selected Nick\nD1:Up\nD2!\n\n"
-		"None\nNext\nScroll Page\nD1!\nD2!\n\n"
-		"None\nPrior\nScroll Page\nD1:Up\nD2!\n\n"
-		"None\nDown\nNext Command\nD1!\nD2!\n\n"
-		"None\nUp\nLast Command\nD1!\nD2!\n\n"
-		"None\nTab\nComplete nick/command\nD1!\nD2!\n\n"
-		"None\nspace\nCheck For Replace\nD1!\nD2!\n\n"
-		"None\nReturn\nCheck For Replace\nD1!\nD2!\n\n"
-		"A\nequal\nChange Page\nD1:1\nD2:Relative\n\n"
-		"C\nTab\nComplete nick/command\nD1:Up\nD2!\n\n"
-		"A\nLeft\nMove front tab left\nD1!\nD2!\n\n"
-		"A\nRight\nMove front tab right\nD1!\nD2!\n\n";
+#define defcfg \
+		"A\nminus\nChange Page\nD1:-1\nD2:Relative\n\n"\
+		"A\n9\nChange Page\nD1:9\nD2!\n\n"\
+		"A\n8\nChange Page\nD1:8\nD2!\n\n"\
+		"A\n7\nChange Page\nD1:7\nD2!\n\n"\
+		"A\n6\nChange Page\nD1:6\nD2!\n\n"\
+		"A\n5\nChange Page\nD1:5\nD2!\n\n"\
+		"A\n4\nChange Page\nD1:4\nD2!\n\n"\
+		"A\n3\nChange Page\nD1:3\nD2!\n\n"\
+		"A\n2\nChange Page\nD1:2\nD2!\n\n"\
+		"A\n1\nChange Page\nD1:1\nD2!\n\n"\
+		"C\no\nInsert in Buffer\nD1:%O\nD2!\n\n"\
+		"C\nb\nInsert in Buffer\nD1:%B\nD2!\n\n"\
+		"C\nk\nInsert in Buffer\nD1:%C\nD2!\n\n"\
+		"S\nNext\nChange Selected Nick\nD1!\nD2!\n\n"\
+		"S\nPrior\nChange Selected Nick\nD1:Up\nD2!\n\n"\
+		"None\nNext\nScroll Page\nD1!\nD2!\n\n"\
+		"None\nPrior\nScroll Page\nD1:Up\nD2!\n\n"\
+		"None\nDown\nNext Command\nD1!\nD2!\n\n"\
+		"None\nUp\nLast Command\nD1!\nD2!\n\n"\
+		"None\nTab\nComplete nick/command\nD1!\nD2!\n\n"\
+		"None\nspace\nCheck For Replace\nD1!\nD2!\n\n"\
+		"None\nReturn\nCheck For Replace\nD1!\nD2!\n\n"\
+		"A\nequal\nChange Page\nD1:1\nD2:Relative\n\n"\
+		"C\nTab\nComplete nick/command\nD1:Up\nD2!\n\n"\
+		"A\nLeft\nMove front tab left\nD1!\nD2!\n\n"\
+		"A\nRight\nMove front tab right\nD1!\nD2!\n\n"
 	char buf[512];
 	int fd;
 
@@ -361,7 +361,7 @@ key_load_defaults ()
 		/* ???!!! */
 		return;
 
-	write (fd, def, strlen (def));
+	write (fd, defcfg, strlen (defcfg));
 	close (fd);
 }
 
@@ -425,7 +425,7 @@ key_dialog_delete (GtkWidget * button, GtkCList * list)
 			last = cur;
 			cur = cur->next;
 		}
-		printf (_("*** key_dialog_delete: couldn't find kb in list!\n"));
+		printf ("*** key_dialog_delete: couldn't find kb in list!\n");
 		/*if (getenv ("XCHAT_DEBUG"))
 			abort ();*/
 	}
@@ -526,8 +526,8 @@ key_dialog_make_toggle (char *label, void *callback, void *option,
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (wid), 0);
 	gtk_signal_connect (GTK_OBJECT (wid), "toggled",
 							  GTK_SIGNAL_FUNC (callback), option);
-	gtk_widget_show (wid);
 	gtk_box_pack_end (GTK_BOX (box), wid, 0, 0, 0);
+	gtk_widget_show (wid);
 
 	return wid;
 }
@@ -1421,7 +1421,7 @@ nick_comp_chng (GtkWidget * t, int updown)
 {
 	struct session *sess;
 	struct User *user, *last = NULL;
-	char *text, nick[64];
+	char *text, nick[NICKLEN], *lastnick, *newtext;
 	int len, slen;
 	GSList *list;
 
@@ -1430,12 +1430,12 @@ nick_comp_chng (GtkWidget * t, int updown)
 		return;
 
 	text = gtk_entry_get_text (GTK_ENTRY (t));
-
 	if (nick_comp_get_nick (text, nick) == -1)
 		return;
-	len = strlen (nick);
 
+	len = strlen (nick);
 	list = sess->userlist;
+
 	while (list)
 	{
 		user = (struct User *) list->data;
@@ -1453,20 +1453,23 @@ nick_comp_chng (GtkWidget * t, int updown)
 				if (list->next == NULL)
 					return;
 				user->weight--;
-				((struct User *) list->next->data)->weight++;
-				snprintf (nick, sizeof (nick), "%s%c ",
-							 ((struct User *) list->next->data)->nick,
-							 prefs.nick_suffix[0]);
+				((struct User *)list->next->data)->weight++;
+				lastnick = ((struct User *)list->next->data)->nick;
 			} else
 			{
 				if (last == NULL)
 					return;
 				user->weight--;
 				last->weight++;
-				snprintf (nick, sizeof (nick), "%s%c ", last->nick, prefs.nick_suffix[0]);
+				lastnick = last->nick;
 			}
-			gtk_entry_set_text (GTK_ENTRY (t), nick);
+
+			newtext = (char *) malloc (strlen (text) + strlen (lastnick) + 1);
+			sprintf (newtext, "%s%s", lastnick, text + strlen (nick));
+			gtk_entry_set_text (GTK_ENTRY (t), newtext);
+			free (newtext);
 			return;
+
 		}
 		last = user;
 		list = list->next;
@@ -1611,13 +1614,13 @@ tab_comp_cmd (GtkWidget * t)
 
 /* In the following 'b4' is *before* the text (just say b4 and before out loud)
    and c5 is *after* (because c5 is next after b4, get it??) --AGL */
-/* pos is the current cursor position of the inputgad --GeEkMaN */
 
 static int
 tab_nick_comp_next (struct session *sess, GtkWidget * wid, char *b4,
-						  char *nick, char *c5, int shift, int pos)
+						  char *nick, char *c5, int shift)
 {
 	struct User *user = 0, *last = NULL;
+	int pos;
 	char buf[4096];
 	GSList *list;
 
@@ -1630,29 +1633,40 @@ tab_nick_comp_next (struct session *sess, GtkWidget * wid, char *b4,
 		last = user;
 		list = list->next;
 	}
+
 	if (!list)
 		return 0;
+
+	if (b4[0] != 0)
+		strcat (b4, " ");
+
 	if (shift)
 	{
 		if (last)
-			snprintf (buf, 4096, "%s %s%s", b4, last->nick, c5);
+			nick = last->nick;
 		else
-			snprintf (buf, 4096, "%s %s%s", b4, nick, c5);
+		{
+			/* making this consistent with the (!shift) behaviour */
+			list = g_slist_last (sess->userlist);
+			if (list)
+				nick = ((struct User *)list->data)->nick;
+		}
 	} else
 	{
 		if (list->next)
-			snprintf (buf, 4096, "%s %s%s", b4,
-						 ((struct User *) list->next->data)->nick, c5);
+			nick = ((struct User *) list->next->data)->nick;
 		else
 		{
 			if (sess->userlist)
-				snprintf (buf, 4096, "%s %s%s", b4,
-							 ((struct User *) sess->userlist->data)->nick, c5);
-			else
-				snprintf (buf, 4096, "%s %s%s", b4, nick, c5);
+				nick = ((struct User *) sess->userlist->data)->nick;
+			/*else
+				nick = nick;*/
 		}
 	}
-	pos = strlen(buf) - strlen(c5);
+
+	snprintf (buf, sizeof (buf), "%s%s%s", b4, nick, c5);
+
+	pos = strlen (buf) - strlen (c5);
 	gtk_entry_set_text (GTK_ENTRY (wid), buf);
 	GTK_EDITABLE (wid)->current_pos = pos;
 
@@ -1663,36 +1677,39 @@ static int
 tab_nick_comp (GtkWidget *t, int shift)
 {
 	struct session *sess;
-	struct User *user = NULL, *match_user = NULL;
-	char *text, not_nick_chars[16] = "";
-	int len, slen, first = 0, i, j, match_count = 0, match_pos = 0;
-	char buf[2048], nick_buf[2048] = {0}, *b4 = NULL, *c5 = NULL, *match_text = NULL,
-		match_char = -1, *nick = NULL, *current_nick = NULL;
-	GSList *list = NULL, *match_list = NULL, *first_match = NULL;
-
-	text = gtk_entry_get_text (GTK_ENTRY (t));
+	struct User *user, *match_user = NULL;
+	char *text, not_nick_chars[5] = { 0, '.', '?', ' ', 0};
+	int len, slen, first, i, cursor_pos, match_count = 0, match_pos = 0;
+	char buf[2048], nick_buf[2048], *b4 = NULL, *c5 = NULL;
+	char *match_text = NULL, *current_nick = NULL;
+	unsigned char match_char = 0xff;
+	GSList *list, *match_list = NULL, *first_match = NULL;
+	int ret = 0;	/* return value */
 
 	sess = find_session_from_inputgad (t);
 	if (sess == NULL)
 		return 0;
 	if (sess->type == SESS_DIALOG)
 		return 0;
-	
-	len = strlen (text);
-	if (!strchr (text, ' '))
+
+	text = gtk_entry_get_text (GTK_ENTRY (t));
+	if (text[0] == '/')
 	{
-		if (text[0] == '/')
+		if (!strchr (text, ' '))
 		{
 			tab_comp_cmd (t);
 			return 0;
 		}
 	}
 
+	/* make a copy, since we use this buffer */
+	text = strdup (text);
+	len = strlen (text);
+
 	/* Is the text more than just a nick? */
+	not_nick_chars[0] = prefs.nick_suffix[0];
 
-	sprintf(not_nick_chars, " .?%c", prefs.nick_suffix[0]);
-
-	if (strcspn (text, not_nick_chars) != strlen (text))
+	if (strcspn (text, not_nick_chars) != len)
 	{
 		/* If we're doing old-style nick completion and the text input widget
 		 * contains a string of the format: "nicknameSUFFIX" or "nicknameSUFFIX ",
@@ -1701,30 +1718,40 @@ tab_nick_comp (GtkWidget *t, int shift)
 		 */
 		if (prefs.old_nickcompletion)
 		{
-			char * space = strchr(text, ' ');
+			char *space = strchr (text, ' ');
 
 			if ((!space || space == &text[len - 1]) &&
 				 text[len - (space ? 2 : 1)] == prefs.nick_suffix[0])
 			{
 				/* This causes the nickname to cycle. */
-				nick_comp_chng(t, shift);
-				return 0;
+				nick_comp_chng (t, shift);
+				goto compdone1; /* free(text) and return 0; */
 			}
 		}
 
-		j = GTK_EDITABLE (t)->current_pos;
+		cursor_pos = GTK_EDITABLE (t)->current_pos;
 
 		/* !! FIXME !! */
-		if (len - j < 0)
-			return 0;
+		if (len - cursor_pos < 0)
+			goto compdone1;	/* free(text) and return 0; */
 
-		b4 = (char *) malloc (len + 1);
+		b4 = (char *) malloc (len + 2);	/* 1 extra for the strcat */
 		c5 = (char *) malloc (len + 1);
-		memmove (c5, &text[j], len - j);
-		c5[len - j] = 0;
+
+		/* this's added for some sanity. or else, nick replacements are just insane. */
+
+		while (text[cursor_pos])
+		{
+			if (text[cursor_pos] == ' ')
+				break;
+			cursor_pos++;
+		}
+
+		memmove (c5, text + cursor_pos, len - cursor_pos);
+		c5[len - cursor_pos] = 0;
 		memcpy (b4, text, len + 1);
 
-		for (i = j - 1; i > -1; i--)
+		for (i = cursor_pos - 1; i >= 0; i--)
 		{
 			if (b4[i] == ' ')
 			{
@@ -1733,24 +1760,30 @@ tab_nick_comp (GtkWidget *t, int shift)
 			}
 			b4[i] = 0;
 		}
-		memmove (text, &text[i + 1], (j - i) + 1);
-		text[(j - i) - 1] = 0;
 
-		if (tab_nick_comp_next (sess, t, b4, text, c5, shift, j))
+		memmove (text, text + i + 1, cursor_pos - i - 1);
+		text[cursor_pos - i - 1] = 0;
+
+		if (tab_nick_comp_next (sess, t, b4, text, c5, shift))
 		{
-			free (b4);
-			free (c5);
-			return 1;
+			ret = 1;
+			goto compdone;
 		}
-		first = 0;
-	} else
-		first = 1;
 
-	len = strlen (text);
+		first = 0;
+
+	} else
+	{
+		first = 1;
+	}
 
 	if (text[0] == 0)
-		return -1;
+	{
+		ret = -1;
+		goto compdone;
+	}
 
+	len = strlen (text);
 	list = sess->userlist;
 
 	/* make a list of matches */
@@ -1769,55 +1802,41 @@ tab_nick_comp (GtkWidget *t, int shift)
 	}
 	match_list = g_slist_reverse (match_list); /* faster then _append */
 	match_count = g_slist_length (match_list);
-	
+
 	/* no matches, return */
 	if (match_count == 0)
-	{
-		if (!first)
-		{
-			free (b4);
-			free (c5);
-		}
-		return 0;
-	}
+		goto compdone;
+
 	first_match = match_list;
 	match_pos = len;
 
 	/* if we have more then 1 match, we want to act like readline and grab common chars */
-	if (!prefs.old_nickcompletion && match_count > 1)
+	if ((!prefs.old_nickcompletion) && (match_count > 1))
 	{
 		while (1)
 		{
 			while (match_list)
 			{
-				current_nick = 
-					(char *) malloc (strlen ((char *) match_list->data) + 1);
-				strcpy (current_nick, (char *) match_list->data);
-				if (match_char == -1)
+				current_nick = match_list->data;
+				if (match_char == 0xff)
 				{
 					match_char = current_nick[match_pos];
-					match_list = g_slist_next (match_list);
-					free (current_nick);
-					continue;
-				}
-				if (tolower (current_nick[match_pos]) != tolower (match_char))
+				} else if (tolower (current_nick[match_pos]) != tolower (match_char))
 				{
-					match_text = (char *) malloc (match_pos);
-					current_nick[match_pos] = '\0';
-					strcpy (match_text, current_nick);
-					free (current_nick);
+					match_text = malloc (match_pos + 1);
+					memcpy (match_text, current_nick, match_pos);
+					match_text[match_pos] = 0;
 					match_pos = -1;
 					break;
 				}
-				match_list = g_slist_next (match_list);
-				free (current_nick);
+				match_list = match_list->next;
 			}
 
 			if (match_pos == -1)
 				break;
 
 			match_list = first_match;
-			match_char = -1;
+			match_char = 0xff;
 			++match_pos;
 		}
 
@@ -1828,44 +1847,56 @@ tab_nick_comp (GtkWidget *t, int shift)
 	/* no match, if we found more common chars among matches, display them in entry */
 	if (match_user == NULL)
 	{
+		nick_buf[0] = 0;
 		while (match_list)
 		{
-			nick = (char *) match_list->data;
-			sprintf (nick_buf, "%s%s ", nick_buf, nick);
-			match_list = g_slist_next (match_list);
+			sprintf (nick_buf, "%s%s ", nick_buf, (char *)match_list->data);
+			match_list = match_list->next;
 		}
 		PrintText (sess, nick_buf);
 
-		if (first) {
+		if (first)
+		{
 			snprintf (buf, sizeof (buf), "%s", match_text);
-			j = strlen(buf);
+			cursor_pos = strlen (buf);
 		}
 		else
 		{
-			snprintf (buf, sizeof (buf), "%s %s%s", b4, match_text, c5);
-			j = strlen (buf) - strlen (c5);
-			free (b4);
-			free (c5);
+			if (b4[0] != 0)
+				strcat (b4, " ");
+			snprintf (buf, sizeof (buf), "%s%s%s", b4, match_text, c5);
+			cursor_pos = strlen (buf) - strlen (c5);
 		}
 		free (match_text);
 	} else
 	{
-		if (first) {
+		if (first)
+		{
 			snprintf (buf, sizeof (buf), "%s%c ", match_user->nick,
 						 prefs.nick_suffix[0]);
-			j = strlen (buf);
+			cursor_pos = strlen (buf);
 		}
 		else
 		{
-			snprintf (buf, sizeof (buf), "%s %s%s", b4, match_user->nick, c5);
-			j = strlen (buf) - strlen (c5);
-			free (b4);
-			free (c5);
+			if (b4[0] != 0)
+				strcat (b4, " ");
+			snprintf (buf, sizeof (buf), "%s%s%s", b4, match_user->nick, c5);
+			cursor_pos = strlen (buf) - strlen (c5);
 		}
 	}
-	gtk_entry_set_text (GTK_ENTRY (t), buf);
-	/* GeEkMaN: Restore the last cursor position (j is used only for this) */
-	GTK_EDITABLE (t)->current_pos = j;
 
-	return 0;
+	gtk_entry_set_text (GTK_ENTRY (t), buf);
+	/* GeEkMaN: Restore the last cursor position */
+	GTK_EDITABLE (t)->current_pos = cursor_pos;
+
+compdone:
+	if (b4)
+		free (b4);
+	if (c5)
+		free (c5);
+
+compdone1:
+	free (text);
+
+	return ret;
 }
