@@ -23,21 +23,13 @@
 #include <sys/stat.h>
 #include <unistd.h>
 #include <fcntl.h>
-#include "../common/xchat.h"
 #include "fe-gtk.h"
-#ifdef USE_XLIB
-#include <gdk/gdkx.h>
-#include <X11/Xlib.h>
-#include <X11/Xatom.h>
-#endif
+#include "../common/xchat.h"
+#include "gtkutil.h"
 
 /* gtkutil.c, just some gtk wrappers */
 
-typedef void (*filereqcallback) (void *, void *, char *file);
-GtkWidget *gtkutil_simpledialog (char *msg);
 extern void path_part (char *file, char *path);
-extern GtkWidget *maingui_new_tab (char *title, char *name,
-											  void *close_callback, void *userdata);
 
 
 struct file_req
@@ -51,7 +43,43 @@ struct file_req
 
 static char last_dir[256] = "";
 
-void
+
+GtkWidget *
+gtkutil_simpledialog (char *msg)
+{
+#ifdef USE_GNOME
+	GtkWidget *dialog =
+		gnome_message_box_new (msg, GNOME_MESSAGE_BOX_INFO, _("Ok"), 0);
+	gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_MOUSE);
+	gtk_widget_show (dialog);
+#else
+	GtkWidget *label, *button, *dialog;
+
+	dialog = gtk_dialog_new ();
+	gtk_window_set_title (GTK_WINDOW (dialog), _("Message"));
+	gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_MOUSE);
+	gtk_container_border_width (GTK_CONTAINER (GTK_DIALOG (dialog)->vbox), 10);
+
+	label = gtk_label_new (msg);
+	gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_LEFT);
+	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), label, TRUE, TRUE, 10);
+	gtk_widget_show (label);
+
+	button = gtk_button_new_with_label (_("Ok"));
+	GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
+	gtk_signal_connect (GTK_OBJECT (button), "clicked",
+							  GTK_SIGNAL_FUNC (gtkutil_destroy), dialog);
+	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->action_area), button,
+							  TRUE, TRUE, 10);
+	gtk_widget_grab_default (button);
+	gtk_widget_show (button);
+
+	gtk_widget_show (dialog);
+#endif
+	return dialog;
+}
+
+static void
 gtkutil_file_req_cancel (GtkWidget * wid, struct file_req *freq)
 {
 	gtk_widget_destroy (freq->dialog);
@@ -59,7 +87,7 @@ gtkutil_file_req_cancel (GtkWidget * wid, struct file_req *freq)
 	free (freq);
 }
 
-void
+static void
 gtkutil_file_req_done (GtkWidget * wid, struct file_req *freq)
 {
 	struct stat st;
@@ -103,9 +131,9 @@ gtkutil_file_req_done (GtkWidget * wid, struct file_req *freq)
 	{
 		free (file);
 		if (freq->write)
-			gtkutil_simpledialog ("Cannot write to that file.");
+			gtkutil_simpledialog (_("Cannot write to that file."));
 		else
-			gtkutil_simpledialog ("Cannot read that file.");
+			gtkutil_simpledialog (_("Cannot read that file."));
 	}
 
 	gtk_widget_destroy (freq->dialog);
@@ -140,30 +168,6 @@ gtkutil_file_req (char *title, void *callback, void *userdata,
 	gtk_widget_show (dialog);
 }
 
-
-extern struct xchatprefs prefs;
-extern GtkWidget *main_window;
-
-GtkWidget *
-gtkutil_window_new (char *title, char *wmclass, int x, int y, void *callback,
-						  gpointer userdata, int allowtab)
-{
-	GtkWidget *win;
-
-	if (prefs.windows_as_tabs && main_window && allowtab)
-		return maingui_new_tab (title, wmclass, callback, userdata);
-
-	win = gtk_window_new (GTK_WINDOW_TOPLEVEL);
-	gtk_window_set_wmclass (GTK_WINDOW (win), wmclass, "X-Chat");
-	gtk_widget_set_usize (win, x, y);
-	gtk_window_set_title (GTK_WINDOW (win), title);
-	gtk_window_set_position (GTK_WINDOW (win), GTK_WIN_POS_MOUSE);
-	if (callback)
-		gtk_signal_connect (GTK_OBJECT (win), "destroy",
-							  		GTK_SIGNAL_FUNC (callback), userdata);
-	return win;
-}
-
 GtkWidget *
 gtkutil_dialog_new (char *title, char *wmclass, void *callback,
 						  gpointer userdata)
@@ -186,41 +190,6 @@ gtkutil_destroy (GtkWidget * igad, GtkWidget * dgad)
 	gtk_widget_destroy (dgad);
 }
 
-GtkWidget *
-gtkutil_simpledialog (char *msg)
-{
-#ifdef USE_GNOME
-	GtkWidget *dialog =
-		gnome_message_box_new (msg, GNOME_MESSAGE_BOX_INFO, _("Ok"), 0);
-	gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_MOUSE);
-	gtk_widget_show (dialog);
-#else
-	GtkWidget *label, *button, *dialog;
-
-	dialog = gtk_dialog_new ();
-	gtk_window_set_title (GTK_WINDOW (dialog), "Message");
-	gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_MOUSE);
-	gtk_container_border_width (GTK_CONTAINER (GTK_DIALOG (dialog)->vbox), 10);
-
-	label = gtk_label_new (msg);
-	gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_LEFT);
-	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), label, TRUE, TRUE, 10);
-	gtk_widget_show (label);
-
-	button = gtk_button_new_with_label ("Ok");
-	GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
-	gtk_signal_connect (GTK_OBJECT (button), "clicked",
-							  GTK_SIGNAL_FUNC (gtkutil_destroy), dialog);
-	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->action_area), button,
-							  TRUE, TRUE, 10);
-	gtk_widget_grab_default (button);
-	gtk_widget_show (button);
-
-	gtk_widget_show (dialog);
-#endif
-	return dialog;
-}
-
 GtkWidget *
 gtkutil_button (GtkWidget * win, char *stock, char *labeltext,
 					 void *callback, gpointer userdata, GtkWidget * box)
@@ -330,22 +299,15 @@ gtkutil_clist_selection (GtkWidget * clist)
 }
 
 void
-gtkutil_null_this_var (GtkWidget * unused, GtkWidget ** dialog)
+add_tip (GtkWidget * wid, char *text)
 {
-	*dialog = 0;
+	GtkTooltips *tip = gtk_tooltips_new ();
+	gtk_tooltips_set_tip (tip, wid, text, 0);
 }
 
 void
-gtkutil_set_icon (GdkWindow * window, GdkPixmap * pixmap, GdkBitmap * mask)
+show_and_unfocus (GtkWidget * wid)
 {
-#ifdef USE_XLIB
-	Atom icon_atom;
-	glong data[2];
-
-	data[0] = GDK_WINDOW_XWINDOW (pixmap);
-	data[1] = GDK_WINDOW_XWINDOW (mask);
-	icon_atom = gdk_atom_intern ("KWM_WIN_ICON", FALSE);
-	gdk_property_change (window, icon_atom, icon_atom,
-								32, GDK_PROP_MODE_REPLACE, (guchar *) data, 2);
-#endif
+	GTK_WIDGET_UNSET_FLAGS (wid, GTK_CAN_FOCUS);
+	gtk_widget_show (wid);
 }
