@@ -1,8 +1,7 @@
+typedef void (*filereqcallback) (void *, void *, char *file);
 
 void gtkutil_file_req (char *title, void *callback, void *userdata,
 							  void *userdata2, int write);
-GtkWidget *gtkutil_window_new (char *title, char *wmclass, int x, int y,
-										 void *callback, gpointer userdata, int);
 GtkWidget *gtkutil_dialog_new (char *title, char *wmclass, void *callback,
 										 gpointer userdata);
 void gtkutil_destroy (GtkWidget * igad, GtkWidget * dgad);
@@ -20,6 +19,5 @@ GtkWidget *gtkutil_clist_new (int columns, char *titles[], GtkWidget * box,
 										void *unselect_callback,
 										gpointer unselect_userdata, int selection_mode);
 int gtkutil_clist_selection (GtkWidget * clist);
-void gtkutil_null_this_var (GtkWidget * unused, GtkWidget ** dialog);
-void gtkutil_set_icon (GdkWindow * window, GdkPixmap * pixmap,
-							  GdkBitmap * mask);
+void add_tip (GtkWidget * wid, char *text);
+void show_and_unfocus (GtkWidget * wid);
