@@ -245,10 +245,24 @@ fe_set_title (struct session *sess)
 void
 fe_set_channel (struct session *sess)
 {
+	char *buf;
+
 	wins_set_name (sess->gui->window, sess->channel);
 	/* toplevel dialogs dont have a changad */
 	if (sess->gui->changad != NULL)
-		gtk_label_set_text (GTK_LABEL (sess->gui->changad), sess->channel);
+	{
+		if (prefs.truncchans && strlen (sess->channel) > prefs.truncchans)
+		{
+			buf = malloc (strlen (sess->channel) + 4);
+			snprintf (buf, prefs.truncchans - 1, "%s", sess->channel);
+			strcat (buf, "..");
+			gtk_label_set_text (GTK_LABEL (sess->gui->changad), buf);
+			free (buf);
+		} else
+		{
+			gtk_label_set_text (GTK_LABEL (sess->gui->changad), sess->channel);
+		}
+	}
 #ifdef USE_PANEL
 	if (sess->gui->panel_button)
 		gtk_label_set_text (GTK_LABEL
@@ -266,7 +280,16 @@ fe_clear_channel (struct session *sess)
 	int i;
 
 	if (sess->waitchannel[0])
-		sprintf(tbuf, "(%s)", sess->waitchannel);
+	{
+		if (prefs.truncchans && strlen (sess->waitchannel) > prefs.truncchans)
+		{
+			snprintf (tbuf, prefs.truncchans, "(%s", sess->waitchannel);
+			strcat (tbuf, "..)");
+		} else
+		{
+			sprintf (tbuf, "(%s)", sess->waitchannel);
+		}
+	}
 	else
 		strcpy (tbuf, _("<none>"));
 	gtk_entry_set_text (GTK_ENTRY (sess->gui->topicgad), "");
@@ -1362,7 +1385,6 @@ gui_make_tab_window (session *sess, GtkWidget *win)
 	}
 
 	main_book = gtk_notebook_new ();
-	gtk_notebook_set_show_border (GTK_NOTEBOOK (main_book), FALSE);
 	maingui_set_tab_pos (prefs.tabs_position);
 	gtk_notebook_set_scrollable ((GtkNotebook *) main_book, TRUE);
 	gtk_signal_connect ((GtkObject *) main_book, "switch_page",
@@ -1651,6 +1673,17 @@ link_cb (GtkWidget *win, session *sess)
 #endif
 			gtk_xtext_refresh (GTK_XTEXT (sess->gui->textgad), 1);
 
+#ifdef USE_GNOME
+		/* avoids a weird refresh glitch where the xtext window is moved
+			to overlap the topicbar. Any resize will fix it... */
+		gdk_window_resize (sess->gui->window->window,
+								 sess->gui->window->allocation.width-1,
+								 sess->gui->window->allocation.height);
+		gdk_window_resize (sess->gui->window->window,	
+								 sess->gui->window->allocation.width,
+								 sess->gui->window->allocation.height);
+#endif
+
 	} else
 	{
 		sess->is_tab = TRUE;
