@@ -652,9 +652,8 @@ menu_shell_title (ZvtTerm * term, int type, char *newtitle, session * sess)
 #include <gdk/gdkx.h>
 #endif
 
-/*                  30 31 32 33 34 35 36  37  30  31 32 33 34  35  36  37 */
-static
-	int color_conv[] =
+/*   30 31 32 33 34 35 36  37  30  31 32 33 34  35  36  37 */
+static short color_conv[] =
 	{ 1, 4, 3, 5, 2, 6, 10, 15, 14, 7, 9, 8, 12, 13, 11, 0, 18, 19 };
 
 static gushort zvt_red[18];
@@ -1735,113 +1734,113 @@ createmenus (void *app, struct session *sess, int bar)
 #else
 
 static struct mymenu mymenu[] = {
-	{M_NEWMENU, N_("X-Chat"), 0, 0, 1},
-	{M_MENU, N_("Server List.."), (menucallback) menu_open_server_list, 0, 1},
-	{M_SEP, 0, 0, 0, 0},
-	{M_MENU, N_("New Server Tab.."), (menucallback) menu_newserver_tab, 0, 1},
+	{N_("X-Chat"), 0, M_NEWMENU, 0, 1},
+	{N_("Server List.."), (menucallback) menu_open_server_list, M_MENU, 0, 1},
+	{0, 0, M_SEP, 0, 0},
+	{N_("New Server Tab.."), (menucallback) menu_newserver_tab, M_MENU, 0, 1},
 	
-	{M_MENU, N_("New Server Window.."), (menucallback) menu_newserver_window, 0, 1},
-	{M_MENU, N_("New Channel Tab.."), (menucallback) menu_newchannel_tab, 0, 1},
-	{M_MENU, N_("New Channel Window.."), (menucallback) menu_newchannel_window, 0, 1},
-	{M_SEP, 0, 0, 0, 0},
+	{N_("New Server Window.."), (menucallback) menu_newserver_window, M_MENU, 0, 1},
+	{N_("New Channel Tab.."), (menucallback) menu_newchannel_tab, M_MENU, 0, 1},
+	{N_("New Channel Window.."), (menucallback) menu_newchannel_window, M_MENU, 0, 1},
+	{0, 0, M_SEP, 0, 0},
 #ifdef USE_ZVT
-	{M_MENU, N_("New Shell Tab.."), (menucallback) menu_newshell_tab, 0, 1},
-	{M_SEP, 0, 0, 0, 0},
+	{N_("New Shell Tab.."), (menucallback) menu_newshell_tab, M_MENU, 0, 1},
+	{0, 0, M_SEP, 0, 0},
 #define menuoffset 0
 #else
 #define menuoffset 2
 #endif
-	{M_MENU, N_("Close"), (menucallback) menu_close, 0, 1},
-	{M_SEP, 0, 0, 0, 0},
-	{M_MENU, N_("Quit"), (menucallback) xchat_exit, 0, 1},	/* 12 */
+	{N_("Close"), (menucallback) menu_close, M_MENU, 0, 1},
+	{0, 0, M_SEP, 0, 0},
+	{N_("Quit"), (menucallback) xchat_exit, M_MENU, 0, 1},	/* 12 */
 
-	{M_NEWMENU, N_("Windows"), 0, 0, 1},
-	{M_MENU, N_("Channel List Window.."), (menucallback) menu_chanlist, 0, 1},
-	{M_MENU, N_("File Send Window.."), (menucallback) menu_dcc_send_win, 0, 1},
-	{M_MENU, N_("File Receive Window.."), (menucallback) menu_dcc_recv_win, 0, 1},
-	{M_MENU, N_("DCC Chat Window.."), (menucallback) menu_dcc_chat_win, 0, 1},
-	{M_MENU, N_("Raw Log Window.."), (menucallback) menu_rawlog, 0, 1},
-	{M_MENU, N_("URL Grabber Window.."), (menucallback) url_opengui, 0, 1},
-	{M_MENU, N_("Notify List Window.."), (menucallback) notify_opengui, 0, 1},
-	{M_MENU, N_("Ignore Window.."), (menucallback) ignore_gui_open, 0, 1},
-	{M_MENU, N_("Ban List Window.."), (menucallback) menu_banlist, 0, 1},
-	{M_SEP, 0, 0, 0, 0},
-	{M_MENU, N_("Flush Buffer"), (menucallback) menu_flushbuffer, 0, 1},
-	{M_MENU, N_("Search Buffer.."), (menucallback) menu_search, 0, 1},
-	{M_MENU, N_("Save Buffer.."), (menucallback) menu_savebuffer, 0, 1},	/* 26 */
+	{N_("Windows"), 0, M_NEWMENU, 0, 1},
+	{N_("Channel List Window.."), (menucallback) menu_chanlist, M_MENU, 0, 1},
+	{N_("File Send Window.."), (menucallback) menu_dcc_send_win, M_MENU, 0, 1},
+	{N_("File Receive Window.."), (menucallback) menu_dcc_recv_win, M_MENU, 0, 1},
+	{N_("DCC Chat Window.."), (menucallback) menu_dcc_chat_win, M_MENU, 0, 1},
+	{N_("Raw Log Window.."), (menucallback) menu_rawlog, M_MENU, 0, 1},
+	{N_("URL Grabber Window.."), (menucallback) url_opengui, M_MENU, 0, 1},
+	{N_("Notify List Window.."), (menucallback) notify_opengui, M_MENU, 0, 1},
+	{N_("Ignore Window.."), (menucallback) ignore_gui_open, M_MENU, 0, 1},
+	{N_("Ban List Window.."), (menucallback) menu_banlist, M_MENU, 0, 1},
+	{0, 0, M_SEP, 0, 0},
+	{N_("Flush Buffer"), (menucallback) menu_flushbuffer, M_MENU, 0, 1},
+	{N_("Search Buffer.."), (menucallback) menu_search, M_MENU, 0, 1},
+	{N_("Save Buffer.."), (menucallback) menu_savebuffer, M_MENU, 0, 1},	/* 26 */
 
-	{M_NEWMENU, N_("User Modes"), 0, 0, 1},
-	{M_MENUTOG, N_("Invisible"), (menucallback) menu_invisible, 1, 1},
-	{M_MENUTOG, N_("Receive Wallops"), (menucallback) menu_wallops, 1, 1},
-	{M_MENUTOG, N_("Receive Server Notices"), (menucallback) menu_servernotice, 1, 1},
-	{M_SEP, 0, 0, 0, 0},
-	{M_MENUTOG, N_("Marked Away"), (menucallback) menu_away, 0, 1},
-	{M_SEP, 0, 0, 0, 0},														/* 33 */
-	{M_MENUTOG, N_("Auto ReJoin on Kick"), (menucallback) menu_autorejoin, 0, 1},
-	{M_MENUTOG, N_("Auto ReConnect to Server"), (menucallback) menu_autoreconnect, 0, 1},
-	{M_MENUTOG, N_("Never-give-up ReConnect"), (menucallback) menu_autoreconnectonfail, 0, 1},
-	{M_SEP, 0, 0, 0, 0},														/* 37 */
-	{M_MENUTOG, N_("Auto Open Dialog Windows"), (menucallback) menu_autodialog, 0, 1},
-	{M_MENUTOG, N_("Auto Accept DCC Chat"), (menucallback) menu_autodccchat, 0, 1},
-	{M_MENUTOG, N_("Auto Accept DCC Send"), (menucallback) menu_autodccsend, 0, 1},
+	{N_("User Modes"), 0, M_NEWMENU, 0, 1},
+	{N_("Invisible"), (menucallback) menu_invisible, M_MENUTOG, 1, 1},
+	{N_("Receive Wallops"), (menucallback) menu_wallops, M_MENUTOG, 1, 1},
+	{N_("Receive Server Notices"), (menucallback) menu_servernotice, M_MENUTOG, 1, 1},
+	{0, 0, M_SEP, 0, 0},
+	{N_("Marked Away"), (menucallback) menu_away, M_MENUTOG, 0, 1},
+	{0, 0, M_SEP, 0, 0},														/* 33 */
+	{N_("Auto ReJoin on Kick"), (menucallback) menu_autorejoin, M_MENUTOG, 0, 1},
+	{N_("Auto ReConnect to Server"), (menucallback) menu_autoreconnect, M_MENUTOG, 0, 1},
+	{N_("Never-give-up ReConnect"), (menucallback) menu_autoreconnectonfail, M_MENUTOG, 0, 1},
+	{0, 0, M_SEP, 0, 0},														/* 37 */
+	{N_("Auto Open Dialog Windows"), (menucallback) menu_autodialog, M_MENUTOG, 0, 1},
+	{N_("Auto Accept DCC Chat"), (menucallback) menu_autodccchat, M_MENUTOG, 0, 1},
+	{N_("Auto Accept DCC Send"), (menucallback) menu_autodccsend, M_MENUTOG, 0, 1},
 
-	{M_NEWMENU, N_("Settings"), 0, 0, 1},	/* 41 */
-	{M_MENU, N_("Setup.."), (menucallback) menu_settings, 0, 1},
-	{M_MENU, N_("Palette.."), (menucallback) palette_edit, 0, 1},
-	{M_MENU, N_("User Commands.."), (menucallback) menu_usercommands, 0, 1},
-	{M_MENU, N_("CTCP Replies.."), (menucallback) menu_ctcpguiopen, 0, 1},
-	{M_MENU, N_("Userlist Buttons.."), (menucallback) menu_ulbuttons, 0, 1},
-	{M_MENU, N_("Userlist Popup.."), (menucallback) menu_ulpopup, 0, 1},
-	{M_MENU, N_("Dialog Buttons.."), (menucallback) menu_dlgbuttons, 0, 1},
-	{M_MENU, N_("Replace.."), (menucallback) menu_rpopup, 0, 1},
-	{M_MENU, N_("URL Handlers.."), (menucallback) menu_urlhandlers, 0, 1},
-	{M_MENU, N_("Edit Event Texts.."), (menucallback) menu_evtpopup, 0, 1},	/* 51 */
-	{M_MENU, N_("Edit Key Bindings.."), (menucallback) menu_keypopup, 0, 1},
-	{M_SEP, 0, 0, 0, 0},
-	{M_MENU, N_("Reload Settings"), (menucallback) menu_reload, 0, 1},
-	{M_SEP, 0, 0, 0, 0},
-	{M_MENU, N_("Save Settings now"), (menucallback) menu_savedefault, 0, 1},
-	{M_MENUTOG, N_("Save Settings on exit"), (menucallback) menu_saveexit, 1, 1},
-	{M_NEWMENU, N_("Scripts & Plugins"), 0, 0, 1},	/* 58 */
+	{N_("Settings"), 0, M_NEWMENU, 0, 1},	/* 41 */
+	{N_("Setup.."), (menucallback) menu_settings, M_MENU, 0, 1},
+	{N_("Palette.."), (menucallback) palette_edit, M_MENU, 0, 1},
+	{N_("User Commands.."), (menucallback) menu_usercommands, M_MENU, 0, 1},
+	{N_("CTCP Replies.."), (menucallback) menu_ctcpguiopen, M_MENU, 0, 1},
+	{N_("Userlist Buttons.."), (menucallback) menu_ulbuttons, M_MENU, 0, 1},
+	{N_("Userlist Popup.."), (menucallback) menu_ulpopup, M_MENU, 0, 1},
+	{N_("Dialog Buttons.."), (menucallback) menu_dlgbuttons, M_MENU, 0, 1},
+	{N_("Replace.."), (menucallback) menu_rpopup, M_MENU, 0, 1},
+	{N_("URL Handlers.."), (menucallback) menu_urlhandlers, M_MENU, 0, 1},
+	{N_("Edit Event Texts.."), (menucallback) menu_evtpopup, M_MENU, 0, 1},	/* 51 */
+	{N_("Edit Key Bindings.."), (menucallback) menu_keypopup, M_MENU, 0, 1},
+	{0, 0, M_SEP, 0, 0},
+	{N_("Reload Settings"), (menucallback) menu_reload, M_MENU, 0, 1},
+	{0, 0, M_SEP, 0, 0},
+	{N_("Save Settings now"), (menucallback) menu_savedefault, M_MENU, 0, 1},
+	{N_("Save Settings on exit"), (menucallback) menu_saveexit, M_MENUTOG, 1, 1},
+	{N_("Scripts & Plugins"), 0, M_NEWMENU, 0, 1},	/* 58 */
 #ifdef USE_PERL
-	{M_MENU, N_("Load Perl Script.."), (menucallback) menu_loadperl, 0, 1},
-	{M_MENU, N_("Unload All Scripts"), (menucallback) menu_unloadall, 0, 1},
-	{M_MENU, N_("Perl List"), (menucallback) menu_perllist, 0, 1},
+	{N_("Load Perl Script.."), (menucallback) menu_loadperl, M_MENU, 0, 1},
+	{N_("Unload All Scripts"), (menucallback) menu_unloadall, M_MENU, 0, 1},
+	{N_("Perl List"), (menucallback) menu_perllist, M_MENU, 0, 1},
 #else
-	{M_MENU, N_("Load Perl Script.."), 0, 0, 0},
-	{M_MENU, N_("Unload All Scripts"), 0, 0, 0},
-	{M_MENU, N_("Perl List"), 0, 0, 0},
+	{N_("Load Perl Script.."), 0, M_MENU, 0, 0},
+	{N_("Unload All Scripts"), 0, M_MENU, 0, 0},
+	{N_("Perl List"), 0, M_MENU, 0, 0},
 #endif
-	{M_SEP, 0, 0, 0, 0},
+	{0, 0, M_SEP, 0, 0},
 #ifdef USE_PLUGIN
-	{M_MENU, N_("Load Plugin (*.so).."), (menucallback) menu_loadplugin, 0, 1},
-	{M_MENU, N_("Unload All Plugins"), (menucallback) menu_unloadallplugins, 0, 1},
-	{M_MENU, N_("Plugin List"), (menucallback) menu_pluginlist, 0, 1},
+	{N_("Load Plugin (*.so).."), (menucallback) menu_loadplugin, M_MENU, 0, 1},
+	{N_("Unload All Plugins"), (menucallback) menu_unloadallplugins, M_MENU, 0, 1},
+	{N_("Plugin List"), (menucallback) menu_pluginlist, M_MENU, 0, 1},
 #else
-	{M_MENU, N_("Load Plugin (*.so).."), 0, 0, 0},
-	{M_MENU, N_("Unload All Plugins"), 0, 0, 0},
-	{M_MENU, N_("Plugin List"), 0, 0, 0},
+	{N_("Load Plugin (*.so).."), 0, M_MENU, 0, 0},
+	{N_("Unload All Plugins"), 0, M_MENU, 0, 0},
+	{N_("Plugin List"), 0, M_MENU, 0, 0},
 #endif
-	{M_SEP, 0, 0, 0, 0},
+	{0, 0, M_SEP, 0, 0},
 #ifdef USE_PYTHON
-	{M_MENU, N_("Load Python Script.."), (menucallback) menu_loadpython, 0, 1},
-	{M_MENU, N_("Python List"), (menucallback) menu_pythonlist, 0, 1},
+	{N_("Load Python Script.."), (menucallback) menu_loadpython, M_MENU, 0, 1},
+	{N_("Python List"), (menucallback) menu_pythonlist, M_MENU, 0, 1},
 #else
-	{M_MENU, N_("Load Python Script.."), 0, 0, 0},
-	{M_MENU, N_("Python List"), 0, 0, 0},
+	{N_("Load Python Script.."), 0, M_MENU, 0, 0},
+	{N_("Python List"), 0, M_MENU, 0, 0},
 #endif
 
-	{M_NEWMENU, N_("User Menu"), (menucallback) - 1, 0, 1},
-	{M_MENU, N_("Edit User Menu"), (menucallback) menu_usermenu, 0, 1},
-	{M_SEP, 0, 0, 0, 0},
+	{N_("User Menu"), (menucallback) - 1, M_NEWMENU, 0, 1},
+	{N_("Edit User Menu"), (menucallback) menu_usermenu, M_MENU, 0, 1},
+	{0, 0, M_SEP, 0, 0},
 
-	{M_NEWMENURIGHT, N_("Help"), 0, 0, 1},
-	{M_MENU, N_("X-Chat Homepage.."), (menucallback) menu_webpage, 0, 1},
-	{M_MENU, N_("Online Docs.."), (menucallback) menu_docs, 0, 1},
-	{M_SEP, 0, 0, 0, 0},
-	{M_MENU, N_("About X-Chat.."), (menucallback) menu_about, 0, 1},
+	{N_("Help"), 0, M_NEWMENURIGHT, 0, 1},
+	{N_("X-Chat Homepage.."), (menucallback) menu_webpage, M_MENU, 0, 1},
+	{N_("Online Docs.."), (menucallback) menu_docs, M_MENU, 0, 1},
+	{0, 0, M_SEP, 0, 0},
+	{N_("About X-Chat.."), (menucallback) menu_about, M_MENU, 0, 1},
 
-	{M_END, 0, 0, 0, 0},
+	{0, 0, M_END, 0, 0},
 };
 
 
