@@ -20,32 +20,24 @@
 
 #define	PLUGIN_C
 
+#include <string.h>
 #include <stdio.h>
-#include <dlfcn.h>
+
+#include "fe-gtk.h"
 #include "../common/xchat.h"
 #include "../common/plugin.h"
-#include "fe-gtk.h"
-#include "gtkutil.h"
+#include "../common/text.h"
 #include "../common/util.h"
+#include "gtkutil.h"
 
 #ifdef USE_PLUGIN
 
-void unhook_all_by_mod (struct module *mod);
-int module_load (char *name, struct session *sess);
-extern int module_unload (char *name, struct session *sess);
 
-extern struct module *modules;
-/*struct module_cmd_set *mod_cmds;*/
-GtkWidget *modlist = 0, *modclist;
-
-/*struct xp_signal *sigroots[NUM_XP];*/
-int (*sighandler[NUM_XP]) (void *, void *, void *, void *, void *, char);
-
-extern void printevent_setup ();
+static GtkWidget *modlist = 0, *modclist;
 
 /* ************** GUI STUFF ***************** */
 
-void
+static void
 module_glist_close (GtkWidget * wid, gpointer * a)
 {
 	gtk_widget_destroy (modlist);
@@ -75,7 +67,7 @@ fe_pluginlist_update (void)
 	}
 }
 
-void
+static void
 module_glist_unload (GtkWidget * wid, struct session *sess)
 {
 	int row;
@@ -91,7 +83,7 @@ module_glist_unload (GtkWidget * wid, struct session *sess)
 void
 module_glist (struct session *sess)
 {
-	static gchar *titles[] = { "Name", "Description" };
+	gchar *titles[] = { _("Name"), _("Description") };
 	GtkWidget *okb, *ulb;
 
 	if (modlist)
@@ -104,7 +96,7 @@ module_glist (struct session *sess)
 	gtk_container_set_border_width (GTK_CONTAINER (GTK_DIALOG (modlist)->vbox),
 											  4);
 	gtk_window_set_position (GTK_WINDOW (modlist), GTK_WIN_POS_CENTER);
-	gtk_window_set_title (GTK_WINDOW (modlist), "X-Chat Plugins");
+	gtk_window_set_title (GTK_WINDOW (modlist), _("X-Chat Plugins"));
 	gtk_window_set_wmclass (GTK_WINDOW (modlist), "plugins", "X-Chat");
 
 	modclist = gtk_clist_new_with_titles (2, titles);
@@ -119,7 +111,7 @@ module_glist (struct session *sess)
 #ifdef	USE_GNOME
 	okb = gnome_stock_button (GNOME_STOCK_BUTTON_OK);
 #else
-	okb = gtk_button_new_with_label ("Ok");
+	okb = gtk_button_new_with_label (_("Ok"));
 #endif
 	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (modlist)->action_area), okb, 1, 1,
 							  10);
@@ -128,7 +120,7 @@ module_glist (struct session *sess)
 							  (gpointer) modlist);
 	gtk_widget_show (okb);
 
-	ulb = gtk_button_new_with_label ("Unload");
+	ulb = gtk_button_new_with_label (_("Unload"));
 	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (modlist)->action_area), ulb, 1, 1,
 							  10);
 	gtk_signal_connect (GTK_OBJECT (ulb), "clicked",
