@@ -17,23 +17,26 @@
  */
 
 #include <stdio.h>
-#include "../common/xchat.h"
-#include "fe-gtk.h"
-#include "gtkutil.h"
-#include <gdk/gdkkeysyms.h>
+#include <string.h>
 #include <fcntl.h>
 #include <unistd.h>
 #include <stdlib.h>
 
-
-extern GdkColor colors[];
+#include "fe-gtk.h"
+#include "../common/xchat.h"
+#include "../common/xchatc.h"
+#include <gdk/gdkkeysyms.h>
+#include "gtkutil.h"
+#include "palette.h"
+#include "wins.h"
+#include "rawlog.h"
 
 
-static int
-close_rawlog (GtkWidget * wid, struct server *serv)
+static void
+close_rawlog (struct server *serv)
 {
-	serv->gui->rawlog_window = 0;
-	return 0;
+	if (is_server (serv))
+		serv->gui->rawlog_window = 0;
 }
 
 static void
@@ -67,7 +70,7 @@ rawlog_keypress (GtkWidget * wid, GdkEventKey * event, struct server *serv)
 {
 	if (event->keyval == GDK_s && event->state & GDK_MOD1_MASK)
 	{
-		gtkutil_file_req ("Save rawlog", rawlog_save, serv, NULL, TRUE);
+		gtkutil_file_req (_("Save rawlog"), rawlog_save, serv, NULL, TRUE);
 		return FALSE;
 	}
 	return TRUE;
@@ -81,16 +84,18 @@ open_rawlog (struct server *serv)
 
 	if (serv->gui->rawlog_window)
 	{
-		gdk_window_show (serv->gui->rawlog_window->window);
+		wins_bring_tofront (serv->gui->rawlog_window);
 		return;
 	}
-	snprintf (tbuf, sizeof tbuf, "X-Chat: Rawlog (%s) [alt-s to save]",
+
+	snprintf (tbuf, sizeof tbuf, _("X-Chat: Rawlog (%s) [alt-s to save]"),
 				 serv->servername);
 	serv->gui->rawlog_window =
-		gtkutil_window_new (tbuf, "rawlog", 450, 100, close_rawlog, serv, TRUE);
+		maingui_window ("rawlog", tbuf, FALSE, TRUE, close_rawlog, serv,
+							 450, 100, &serv->gui->rawlog_window);
 
 	hbox = gtk_hbox_new (FALSE, 0);
-	gtk_container_add (GTK_CONTAINER (serv->gui->rawlog_window), hbox);
+	gtk_container_add (GTK_CONTAINER (wins_get_vbox (serv->gui->rawlog_window)), hbox);
 	gtk_widget_show (hbox);
 
 	serv->gui->rawlog_textlist = gtk_text_new (0, 0);
