@@ -636,10 +636,10 @@ edit_entry_clicked (GtkWidget * wid, GtkCTreeNode * temp)
 		entry_password = table_entry (_("Password:"), tab, 85,
 												editentry->password, 1, 2);
 
-		entry_channel = table_entry (_("Channels:"), tab, CHANLEN,
+		entry_channel = table_entry (_("Channels:"), tab, CHANLEN - 1,
 											  editentry->channel, 1, 3);
 
-		entry_nick = table_entry (_("Nickname:"), tab, NICKLEN,
+		entry_nick = table_entry (_("Nickname:"), tab, NICKLEN - 1,
 										  editentry->nick, 1, 4);
 
 		entry_eomcmd = table_entry (_("Connect Cmd:"), tab, 71,
