@@ -434,6 +434,35 @@ static struct defaultserv dserv[] =
 	{"", "wakka.d-t-net.de", "Dark-Tou-Net Server, Frankfurt / Main (Germany)", 6667},
 	{"", "ENDSUB", "", 0},
 
+	{"", "SUB", "AmigaNet", 0},
+	{"", "linux.us.amiganet.org", "Amiganet USA", 6667},
+	{"", "whiterose.us.amiganet.org", "Amiganet USA", 6667},
+	{"", "thule.no.amiganet.org", "Amiganet Norway", 6667},
+	{"", "dynarc.se.amiganet.org", "Amiganet Sweden", 6667},
+	{"", "fullcomp.au.amiganet.org", "Amiganet Australia", 6667},
+	{"", "spod.uk.amiganet.org", "Amiganet UK", 6667},
+	{"", "ENDSUB", "", 0},
+
+	{"", "SUB", "IRCSoulZ", 0},
+	{"", "irc.ircsoulz.net", "irc.ircsoulz.net", 6667},
+	{"", "ENDSUB", "", 0},
+  
+	{"", "SUB", "QuakeNet", 0},
+	{"", "irc.quakenet.org", "QuakeNet", 6667},
+	{"", "irc.se.quakenet.org", "QuakeNet Sweden", 6667},
+	{"", "irc.dk.quakenet.org", "QuakeNet Denmark", 6667},
+	{"", "irc.no.quakenet.org", "QuakeNet Norway", 6667},
+	{"", "irc.fi.quakenet.org", "QuakeNet Finland", 6667},
+	{"", "irc.be.quakenet.org", "QuakeNet Belgium", 6667},
+	{"", "irc.uk.quakenet.org", "QuakeNet UK", 6667},
+	{"", "irc.de.quakenet.org", "QuakeNet Germany", 6667},
+	{"", "irc.it.quakenet.org", "QuakeNet Italy", 6667},
+	{"", "ENDSUB", "", 0},
+
+	{"", "SUB", "irc.cyberarmy.com", 0},
+	{"#cyberarmy", "irc.cyberarmy.com", "irc.cyberarmy.com", 6667},
+	{"", "ENDSUB", "", 0},
+
 /*	{"", "SUB", "", 0},
 	{"", "", "", 6667},
 	{"", "ENDSUB", "", 0},*/
