@@ -1536,16 +1536,21 @@ settings_page_irc_away (struct session *sess, GtkWidget * vbox)
 	gint row_index;
 
 	wid = settings_create_group (vbox, _("General"));
+
 	tog = settings_create_toggle (_("Show away once"), wid,
-											prefs.show_away_once, settings_ptoggle_check,
-											&(sess->setup->prefs.show_away_once));
+			prefs.show_away_once, settings_ptoggle_check,
+			&(sess->setup->prefs.show_away_once));
 	add_tip (tog, _("Only show away messages the first time they're seen"));
+
 	tog = settings_create_toggle (_("Announce away messsages"), wid,
-											prefs.show_away_message,
-											settings_ptoggle_check,
-											&(sess->setup->prefs.show_away_message));
-	add_tip (tog,
-				_("Announce your away message to the channel(s) you are in"));
+			prefs.show_away_message, settings_ptoggle_check,
+			&(sess->setup->prefs.show_away_message));
+	add_tip (tog, _("Announce your away message to the channel(s) you are in"));
+
+	tog = settings_create_toggle (_("Automatic unmark away"), wid,
+			prefs.auto_unmark_away, settings_ptoggle_check,
+			&(sess->setup->prefs.auto_unmark_away));
+	add_tip (tog, _("When typing is started, the away flag is unset"));
 
 	wid = settings_create_group (vbox, _("Your away settings"));
 	tab = settings_create_table (wid);
