@@ -230,20 +230,17 @@ pevent_dialog_hfill (GtkWidget * list, int e)
 	if (!text_event (e))
 		return;
 
-	text = _(te[e].help[i]);
-
 	gtk_clist_clear (GTK_CLIST (list));
-	while (text)
+	while (i < te[e].num_args)
 	{
-		snprintf (buf, sizeof (buf), "%d", i + 1);
+		text = _(te[e].help[i]);
+		i++;
+		snprintf (buf, sizeof (buf), "%d", i);
 		if (text[0] == '\001')
 			text++;
 		nnew[0] = buf;
 		nnew[1] = text;
 		gtk_clist_append (GTK_CLIST (list), nnew);
-
-		i++;
-		text = _(te[e].help[i]);
 	}
 }
 
