@@ -192,6 +192,7 @@ gtk_xtext_init (GtkXText * xtext)
 	xtext->skip_stamp = FALSE;
 	xtext->do_underline_fills_only = FALSE;
 	xtext->jump_out_early = FALSE;
+	xtext->recycle = FALSE;
 	xtext->tint_red = xtext->tint_green = xtext->tint_blue = TINT_VALUE;
 
 	xtext->adj = (GtkAdjustment *) gtk_adjustment_new (0, 0, 0, 1, 0, 0);
@@ -500,16 +501,13 @@ gtk_xtext_size_allocate (GtkWidget * widget, GtkAllocation * allocation)
 	GtkXText *xtext = GTK_XTEXT (widget);
 
 	if (allocation->width == widget->allocation.width &&
-		 allocation->height == widget->allocation.height &&
-		 allocation->x == widget->allocation.x &&
-		 allocation->y == widget->allocation.y)
+		 allocation->height == widget->allocation.height)
 		return;
 
 	widget->allocation = *allocation;
 	if (GTK_WIDGET_REALIZED (widget))
 	{
-		gdk_window_move_resize (widget->window,
-										allocation->x, allocation->y,
+		gdk_window_move_resize (widget->window, allocation->x, allocation->y,
 										allocation->width, allocation->height);
 		gtk_xtext_calc_lines (xtext, FALSE);
 #ifdef USE_XLIB
@@ -544,17 +542,24 @@ gtk_xtext_draw (GtkWidget * widget, GdkRectangle * area)
 		{
 			xtext->last_win_x = x;
 			xtext->last_win_y = y;
-			gtk_xtext_free_trans (xtext);
-			gtk_xtext_load_trans (xtext);
+			if (xtext->shaded)
+			{
+				xtext->recycle = TRUE;
+				gtk_xtext_load_trans (xtext);
+				xtext->recycle = FALSE;
+			} else
+			{
+				gtk_xtext_free_trans (xtext);
+				gtk_xtext_load_trans (xtext);
+			}
 		}
 	}
 #endif
 
+	gtk_xtext_render_page (xtext);
 	if (xtext->scrollbar_down)
 		gtk_adjustment_set_value (xtext->adj,
 											xtext->adj->upper - xtext->adj->page_size);
-	gtk_xtext_render_page (xtext);
-
 	xtext->skip_exposure = TRUE;
 	gtk_idle_add ((GtkFunction)gtk_xtext_idle, xtext);
 }
@@ -2231,18 +2236,20 @@ get_desktop_window (Window the_window)
 static Pixmap
 get_pixmap_prop (Window the_window)
 {
-	Atom prop, type;
+	Atom type;
 	int format;
 	unsigned long length, after;
 	unsigned char *data;
 	Pixmap pix = None;
+	static Atom prop = None;
 
 	if (desktop_window == None)
 		desktop_window = get_desktop_window (the_window);
 	if (desktop_window == None)
 		desktop_window = GDK_ROOT_WINDOW ();
 
-	prop = XInternAtom (GDK_DISPLAY (), "_XROOTPMAP_ID", True);
+	if (prop == None)
+		prop = XInternAtom (GDK_DISPLAY (), "_XROOTPMAP_ID", True);
 	if (prop == None)
 		return None;
 
@@ -2260,10 +2267,83 @@ get_pixmap_prop (Window the_window)
 	return pix;
 }
 
+#ifdef USE_MMX
+
+#include "mmx_cmod.h"
+
+static GdkPixmap *
+shade_pixmap_mmx (GtkXText * xtext, Pixmap p, int x, int y, int w, int h)
+{
+	int dummy, width, height, depth;
+	GdkPixmap *shaded_pix;
+	Window root;
+	Pixmap tmp;
+	XImage *ximg;
+	XGCValues gcv;
+	GC tgc;
+
+	XGetGeometry (GDK_DISPLAY (), p, &root, &dummy, &dummy, &width, &height,
+					  &dummy, &depth);
+
+	if (width < x + w || height < y + h || x < 0 || y < 0)
+	{
+		gcv.subwindow_mode = IncludeInferiors;
+		gcv.graphics_exposures = False;
+		tgc = XCreateGC (GDK_DISPLAY (), p, GCGraphicsExposures|GCSubwindowMode,
+							  &gcv);
+		tmp = XCreatePixmap (GDK_DISPLAY (), p, w, h, depth);
+		XSetTile (GDK_DISPLAY (), tgc, p);
+		XSetFillStyle (GDK_DISPLAY (), tgc, FillTiled);
+		XSetTSOrigin (GDK_DISPLAY (), tgc, -x, -y);
+		XFillRectangle (GDK_DISPLAY (), tmp, tgc, 0, 0, w, h);
+		XFreeGC (GDK_DISPLAY (), tgc);
+
+		ximg = XGetImage (GDK_DISPLAY (), tmp, 0, 0, w, h, -1, ZPixmap);
+		XFreePixmap (GDK_DISPLAY (), tmp);
+	} else
+	{
+		ximg = XGetImage (GDK_DISPLAY (), p, x, y, w, h, -1, ZPixmap);
+	}
+
+	switch (depth)
+	{
+	/* 1 and 8 not supported */
+	case 15:
+		shade_ximage_15_mmx (ximg->data, ximg->bytes_per_line, w, h,
+						xtext->tint_red, xtext->tint_green, xtext->tint_blue);
+		break;
+	case 16:
+		shade_ximage_16_mmx (ximg->data, ximg->bytes_per_line, w, h,
+						xtext->tint_red, xtext->tint_green, xtext->tint_blue);
+		break;
+	case 24:
+		if (ximg->bits_per_pixel != 32)
+			break;
+	case 32:
+		shade_ximage_32_mmx (ximg->data, ximg->bytes_per_line, w, h,
+						xtext->tint_red, xtext->tint_green, xtext->tint_blue);
+		break;
+	}
+
+	if (xtext->recycle)
+		shaded_pix = xtext->pixmap;
+	else
+		shaded_pix = gdk_pixmap_new (GTK_WIDGET (xtext)->window, w, h, depth);
+
+	XPutImage (GDK_DISPLAY (), GDK_WINDOW_XWINDOW (shaded_pix),
+				  GDK_GC_XGC (xtext->fgc), ximg, 0, 0, 0, 0, w, h);
+
+	XDestroyImage (ximg);
+
+	return shaded_pix;
+}
+
+#endif	/* !USE_MMX */
+
 #ifdef USE_GDK_PIXBUF
 
 static GdkPixmap *
-create_shaded_pixmap (GtkXText * xtext, Pixmap p, int x, int y, int w, int h)
+shade_pixmap_gdk (GtkXText * xtext, Pixmap p, int x, int y, int w, int h)
 {
 	GdkPixmap *pp, *tmp, *shaded_pixmap;
 	GdkPixbuf *pixbuf;
@@ -2336,14 +2416,48 @@ create_shaded_pixmap (GtkXText * xtext, Pixmap p, int x, int y, int w, int h)
 		buf+=rowstride;
 	}
 
-	gdk_pixbuf_render_pixmap_and_mask (pixbuf, &shaded_pixmap, NULL, 0);
+	/* reuse the same pixmap to save a few cycles */
+	if (xtext->recycle)
+	{
+		shaded_pixmap = xtext->pixmap;
+		gdk_pixbuf_render_to_drawable (pixbuf, shaded_pixmap, xtext->fgc, 0, 0,
+												 0, 0, w, h, GDK_RGB_DITHER_NORMAL, 0, 0);
+	} else
+	{
+		gdk_pixbuf_render_pixmap_and_mask (pixbuf, &shaded_pixmap, NULL, 0);
+	}
 	gdk_pixbuf_unref (pixbuf);
 
 	return shaded_pixmap;
 }
 
+#endif /* !USE_GDK_PIXBUF */
+
+#if defined(USE_GDK_PIXBUF) || defined(USE_MMX)
+
+static GdkPixmap *
+shade_pixmap (GtkXText * xtext, Pixmap p, int x, int y, int w, int h)
+{
+#ifdef USE_MMX
+
+	if (have_mmx () && xtext->depth != 8)
+		return shade_pixmap_mmx (xtext, p, x, y, w, h);
+
+#ifdef USE_GDK_PIXBUF
+	return shade_pixmap_gdk (xtext, p, x, y, w, h);
+#else
+	return NULL;
 #endif
 
+#else
+
+	return shade_pixmap_gdk (xtext, p, x, y, w, h);
+
+#endif /* !USE_MMX */
+}
+
+#endif /* !USE_TINT */
+
 /* free transparency xtext->pixmap */
 
 static void
@@ -2386,22 +2500,27 @@ gtk_xtext_load_trans (GtkXText * xtext)
 
 	gdk_window_get_origin (widget->window, &x, &y);
 
-#ifdef USE_GDK_PIXBUF
+#if defined(USE_GDK_PIXBUF) || defined(USE_MMX)
 	if (xtext->shaded)
 	{
 		int width, height;
 		gdk_window_get_size (GTK_WIDGET (xtext)->window, &width, &height);
-		xtext->pixmap =
-			create_shaded_pixmap (xtext, rootpix, x, y, width, height);
+		xtext->pixmap = shade_pixmap (xtext, rootpix, x, y, width, height);
+		if (xtext->pixmap == NULL)
+		{
+			xtext->shaded = 0;
+			goto noshade;
+		}
 		gdk_gc_set_tile (xtext->bgc, xtext->pixmap);
 		gdk_gc_set_ts_origin (xtext->bgc, 0, 0);
 	} else
 	{
 #endif
+noshade:
 		xtext->pixmap = gdk_pixmap_foreign_new (rootpix);
 		gdk_gc_set_tile (xtext->bgc, xtext->pixmap);
 		gdk_gc_set_ts_origin (xtext->bgc, -x, -y);
-#ifdef USE_GDK_PIXBUF
+#if defined(USE_GDK_PIXBUF) || defined(USE_MMX)
 	}
 #endif
 	gdk_gc_set_fill (xtext->bgc, GDK_TILED);
@@ -2730,7 +2849,7 @@ gtk_xtext_set_background (GtkXText * xtext, GdkPixmap * pixmap, int trans,
 {
 	GdkGCValues val;
 
-#ifndef USE_GDK_PIXBUF
+#if !defined(USE_GDK_PIXBUF) && !defined(USE_MMX)
 	shaded = FALSE;
 #endif
 
